# coding: utf-8

# flake8: noqa

"""
    Flywheel

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import


import codecs
import os
import os.path
import sys
import six
import time
import math
import io
import platform
import logging
import mimetypes
from packaging import version
from urllib.parse import urlparse, parse_qs

log = logging.getLogger('Flywheel')

from flywheel.configuration import Configuration
from flywheel.api_client import ApiClient
from flywheel.partial_reader import PartialReader
from flywheel.view_builder import ViewBuilder
from flywheel.finder import Finder
import flywheel.api

SDK_VERSION = "18.5.0"

def config_from_api_key(api_key):
    parts = api_key.split(':')
    if len(parts) < 2:
        raise Exception('Invalid API key')

    host = parts[0]
    if len(parts) == 2:
        key = parts[1]
        port = '443'
    else:
        port = parts[1]
        key = parts[-1]

    if '__force_insecure' in parts:
        scheme = 'http'
    else:
        scheme = 'https'

    config = Configuration()
    config.host = '{}://{}:{}/api'.format(scheme, host, port)
    config.api_key = {'Authorization': key}

    if len(key) == 57:
        config.api_key_prefix = {'Authorization': 'Bearer'}
    else:
        config.api_key_prefix = {'Authorization': 'scitran-user'}

    return config


class Flywheel:
    def __init__(self, api_key, minimum_supported_major_version=0, root=False,
                 skip_version_check=True, subjects_in_resolver=None,
                 request_timeout=None, connect_timeout=None):

        # Check that the client caller is expecting the minimum supported version
        if minimum_supported_major_version < 11:
            raise Exception('The Flywheel CLI is expecting a version before v11'
                ' of the Flywheel SDK. Please use flywheel.Client() instead of'
                ' flywheel.Flywheel() if your are not the Flywheel CLI.')

        # Parse API Key and configure api_client
        config = config_from_api_key(api_key)
        self.api_client = ApiClient(
            config,
            context=self,
            request_timeout=request_timeout,
            connect_timeout=connect_timeout
        )

        # Root mode (Deprecated)
        if root:
            log.warning('Root mode is deprecated')
            self.api_client.set_default_query_param('exhaustive', 'true')

        self.api_client.user_agent = 'Flywheel SDK/{} (Python {}; {})'.format(SDK_VERSION,
            platform.python_version(), platform.system())

        # Initialize Apis
        self.acquisitions_api = flywheel.api.AcquisitionsApi(self.api_client)
        self.analyses_api = flywheel.api.AnalysesApi(self.api_client)
        self.audit_trail_api = flywheel.api.AuditTrailApi(self.api_client)
        self.auth_api = flywheel.api.AuthApi(self.api_client)
        self.batch_api = flywheel.api.BatchApi(self.api_client)
        self.bulk_api = flywheel.api.BulkApi(self.api_client)
        self.change_log_api = flywheel.api.ChangeLogApi(self.api_client)
        self.collections_api = flywheel.api.CollectionsApi(self.api_client)
        self.config_api = flywheel.api.ConfigApi(self.api_client)
        self.containers_api = flywheel.api.ContainersApi(self.api_client)
        self.data_view_executions_api = flywheel.api.DataViewExecutionsApi(self.api_client)
        self.dataexplorer_api = flywheel.api.DataexplorerApi(self.api_client)
        self.devices_api = flywheel.api.DevicesApi(self.api_client)
        self.dimse_api = flywheel.api.DimseApi(self.api_client)
        self.download_api = flywheel.api.DownloadApi(self.api_client)
        self.files_api = flywheel.api.FilesApi(self.api_client)
        self.gears_api = flywheel.api.GearsApi(self.api_client)
        self.groups_api = flywheel.api.GroupsApi(self.api_client)
        self.jobs_api = flywheel.api.JobsApi(self.api_client)
        self.jupyterlab_servers_api = flywheel.api.JupyterlabServersApi(self.api_client)
        self.modalities_api = flywheel.api.ModalitiesApi(self.api_client)
        self.packfiles_api = flywheel.api.PackfilesApi(self.api_client)
        self.projects_api = flywheel.api.ProjectsApi(self.api_client)
        self.reports_api = flywheel.api.ReportsApi(self.api_client)
        self.resolve_api = flywheel.api.ResolveApi(self.api_client)
        self.roles_api = flywheel.api.RolesApi(self.api_client)
        self.sessions_api = flywheel.api.SessionsApi(self.api_client)
        self.site_api = flywheel.api.SiteApi(self.api_client)
        self.subjects_api = flywheel.api.SubjectsApi(self.api_client)
        self.tree_api = flywheel.api.TreeApi(self.api_client)
        self.uids_api = flywheel.api.UidsApi(self.api_client)
        self.upload_api = flywheel.api.UploadApi(self.api_client)
        self.users_api = flywheel.api.UsersApi(self.api_client)
        self.views_api = flywheel.api.ViewsApi(self.api_client)

        # Finder objects
        self.users = Finder(self, 'get_all_users')
        self.groups = Finder(self, 'get_all_groups')
        self.projects = Finder(self, 'get_all_projects')
        self.subjects = Finder(self, 'get_all_subjects')
        self.sessions = Finder(self, 'get_all_sessions')
        self.acquisitions = Finder(self, 'get_all_acquisitions')
        self.jobs = Finder(self, 'get_all_jobs')
        self.gears = Finder(self, 'get_all_gears')
        self.collections = Finder(self, 'get_all_collections')
        self.data_view_executions = Finder(self, 'get_all_data_view_executions')
        self.files = Finder(self, 'get_all_files')
        self.analyses = Finder(self, 'get_all_analyses')

        # Overwrite catalog_list endpoint with a Finder because it can only work with
        # pagination
        catalog_list = Finder(self, 'catalog_list')
        catalog_list._func
        self.catalog_list = catalog_list

        # Enable subjects in resolver by default
        if subjects_in_resolver is None:
            subjects_in_resolver = os.environ.get('FLYWHEEL_SDK_SUBJECTS_IN_RESOLVER', '').lower() not in ['0', 'false']

        self.enable_feature('Safe-Redirect')
        self.enable_feature('multipart_signed_url')


    def add_acquisition(self, body, **kwargs):  # noqa: E501
        """Create a new acquisition

        Create a new acquisition

        :param AcquisitionInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.acquisitions_api.add_acquisition(body, **kwargs)


    def add_acquisition_analysis(self, cid, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis.

        :param str cid: (required)
        :param union[AdhocAnalysisInput,JobAnalysisInput] body: (required)
        :param bool job: returns job_id instead of analysis.id
        :param bool job: returns job_id instead of analysis.id
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.acquisitions_api.add_acquisition_analysis(cid, body, **kwargs)


    def add_acquisition_analysis_note(self, container_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to acquisition analysis.


        :param str container_id: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.acquisitions_api.add_acquisition_analysis_note(container_id, analysis_id, body, **kwargs)


    def add_acquisition_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to acquisition.


        :param str container_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.acquisitions_api.add_acquisition_note(container_id, body, **kwargs)


    def add_acquisition_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to acquisition.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.add_acquisition_tag(cid, body, **kwargs)


    def add_acquisition_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to acquisition

        Add multiple tags to acquisition

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.acquisitions_api.add_acquisition_tags(cid, body, **kwargs)


    def delete_acquisition(self, acquisition_id, **kwargs):  # noqa: E501
        """Delete a acquisition

        Read-write project permissions are required to delete an acquisition. </br>Admin project permissions are required if the acquisition contains data uploaded by sources other than users and jobs.

        :param str acquisition_id: (required)
        :param ContainerDeleteReason delete_reason: Provide a reason for the deletion
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.acquisitions_api.delete_acquisition(acquisition_id, **kwargs)


    def delete_acquisition_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis

        Delete an analysis for a container.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param ContainerDeleteReason delete_reason: Provide a reason for the deletion
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.acquisitions_api.delete_acquisition_analysis(cid, analysis_id, **kwargs)


    def delete_acquisition_analysis_note(self, cid, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from acquisition analysis.

        Remove a note from acquisition analysis.

        :param str cid: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.acquisitions_api.delete_acquisition_analysis_note(cid, analysis_id, note_id, **kwargs)


    def delete_acquisition_file(self, cid, filename, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str cid: (required)
        :param str filename: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.acquisitions_api.delete_acquisition_file(cid, filename, **kwargs)


    def delete_acquisition_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Remove a note from acquisition

        Remove a note from acquisition

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.acquisitions_api.delete_acquisition_note(cid, note_id, **kwargs)


    def delete_acquisition_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.acquisitions_api.delete_acquisition_tag(cid, value, **kwargs)


    def delete_acquisition_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete multiple tags from acquisition

        Delete multiple tags from acquisition

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.acquisitions_api.delete_acquisition_tags(cid, body, **kwargs)


    def download_file_from_acquisition(self, acquisition_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str acquisition_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.acquisitions_api.download_file_from_acquisition(acquisition_id, file_name, dest_file, **kwargs)


    def get_acquisition_file_zip_info(self, acquisition_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str acquisition_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.acquisitions_api.get_acquisition_file_zip_info(acquisition_id, file_name, **kwargs)


    def get_acquisition_download_url(self, acquisition_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str acquisition_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.acquisitions_api.get_acquisition_download_ticket(acquisition_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_acquisition_analysis(self, acquisition_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.acquisitions_api.download_input_from_acquisition_analysis(acquisition_id, analysis_id, filename, dest_file, **kwargs)


    def get_acquisition_analysis_input_zip_info(self, acquisition_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.acquisitions_api.get_acquisition_analysis_input_zip_info(acquisition_id, analysis_id, filename, **kwargs)


    def get_acquisition_analysis_input_download_url(self, acquisition_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.acquisitions_api.get_acquisition_analysis_input_download_ticket(acquisition_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_acquisition_analysis(self, acquisition_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.acquisitions_api.download_output_from_acquisition_analysis(acquisition_id, analysis_id, filename, dest_file, **kwargs)


    def get_acquisition_analysis_output_zip_info(self, acquisition_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.acquisitions_api.get_acquisition_analysis_output_zip_info(acquisition_id, analysis_id, filename, **kwargs)


    def get_acquisition_analysis_output_download_url(self, acquisition_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.acquisitions_api.get_acquisition_analysis_output_download_ticket(acquisition_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_acquisition(self, acquisition_id, **kwargs):  # noqa: E501
        """Get a single acquisition

        Get a single acquisition

        :param str acquisition_id: (required)
        :param JoinType join:
        :param bool join_avatars: add name and avatar to notes
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: AcquisitionOutput
        """
        return self.acquisitions_api.get_acquisition(acquisition_id, **kwargs)


    def get_acquisition_analyses(self, cid, **kwargs):  # noqa: E501
        """Get analyses for acquisition.

        Returns analyses that directly belong to this resource.

        :param str cid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool inflate_job:
        :param bool join_avatars:
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[union[AnalysisListOutput,AnalysisListOutputInflatedJob]]]
        """
        return self.acquisitions_api.get_acquisition_analyses(cid, **kwargs)


    def get_acquisition_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.

        Get an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool join_avatars:
        :param JoinType join:
        :param bool async_: Perform the request asynchronously
        :return: union[AnalysisOutputInflatedJob,AnalysisOutput]
        """
        return self.acquisitions_api.get_acquisition_analysis(cid, analysis_id, **kwargs)


    def get_acquisition_file_info(self, cid, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str cid: (required)
        :param str filename: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.acquisitions_api.get_acquisition_file_info(cid, filename, **kwargs)


    def get_acquisition_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Get a note on acquisition.

        Get a note on acquisition

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.acquisitions_api.get_acquisition_note(cid, note_id, **kwargs)


    def get_acquisition_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.acquisitions_api.get_acquisition_tag(cid, value, **kwargs)


    def get_all_acquisitions(self, **kwargs):  # noqa: E501
        """Get a list of acquisitions

        Get a list of acquisitions.

        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param JoinType join:
        :param bool join_avatars: add name and avatar to notes
        :param str collection_id:
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[AcquisitionListOutput],Page]
        """
        return self.acquisitions_api.get_all_acquisitions(**kwargs)


    def modify_acquisition(self, acquisition_id, body, **kwargs):  # noqa: E501
        """Update an acquisition

        Update an acquisition

        :param str acquisition_id: (required)
        :param AcquisitionModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.modify_acquisition(acquisition_id, body, **kwargs)


    def modify_acquisition_analysis(self, cid, analysis_id, body, **kwargs):  # noqa: E501
        """Modify an analysis.

        Modify an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param AnalysisModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.modify_acquisition_analysis(cid, analysis_id, body, **kwargs)


    def modify_acquisition_file(self, cid, filename, body, **kwargs):  # noqa: E501
        """Modify a file&#x27;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list)

        :param str cid: (required)
        :param str filename: (required)
        :param FileModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.modify_acquisition_file(cid, filename, body, **kwargs)


    def modify_acquisition_file_classification(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.modify_acquisition_file_classification(cid, filename, body, **kwargs)


    def modify_acquisition_file_info(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update info for a particular file.

        Modify and return the file 'info' field

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.modify_acquisition_file_info(cid, filename, body, **kwargs)


    def modify_acquisition_info(self, cid, body, **kwargs):  # noqa: E501
        """Update or replace info for a acquisition.

        Update or replace info for a acquisition.

        :param str cid: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.acquisitions_api.modify_acquisition_info(cid, body, **kwargs)


    def modify_acquisition_note(self, cid, note_id, body, **kwargs):  # noqa: E501
        """Update a note on acquisition.

        Update a note on acquisition

        :param str cid: (required)
        :param str note_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.acquisitions_api.modify_acquisition_note(cid, note_id, body, **kwargs)


    def rename_acquisition_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.acquisitions_api.rename_acquisition_tag(cid, value, body, **kwargs)


    def upload_file_to_acquisition(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload a file to acquisition.


        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param bool preserve_metadata:
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str metadata: Metadata object as a JSON-encoded string
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[FileOutput],UploadTicketOutput]
        """
        if signed:
            signed_result = self.signed_upload_file_to_acquisition(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.acquisitions_api.upload_file_to_acquisition(container_id, file, **kwargs)


    def upload_output_to_acquisition_analysis(self, cid, analysis_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload an output file to analysis.

        Upload an output file to analysis

        :param str cid: (required)
        :param str analysis_id: (required)
        :param str file: The file to upload (required)
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: list[FileOutput]
        """
        if signed:
            signed_result = self.signed_upload_output_to_acquisition_analysis(cid, analysis_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.acquisitions_api.upload_output_to_acquisition_analysis(cid, analysis_id, file, **kwargs)


    def add_analysis_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to analysis.

        Add a note to analysis.

        :param str container_id: Container id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.analyses_api.add_analysis_note(container_id, body, **kwargs)


    def add_analysis_tag(self, container_id, body, **kwargs):  # noqa: E501
        """Add a tag to analysis.

        Propagates changes to projects, sessions and acquisitions

        :param str container_id: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.analyses_api.add_analysis_tag(container_id, body, **kwargs)


    def delete_analysis(self, analysis_id, **kwargs):  # noqa: E501
        """Delete an analysis

        Delete an analysis by its id  Args:     analysis_id: The id of the analysis     auth_session: The auth session     delete_reason: The reason for deletion (required when audit-trail is enabled)

        :param str analysis_id: 24-char hex analysis id (required)
        :param ContainerDeleteReason delete_reason:
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.analyses_api.delete_analysis(analysis_id, **kwargs)


    def delete_analysis_note(self, container_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from analysis

        Remove a note from analysis

        :param str container_id: Container id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.analyses_api.delete_analysis_note(container_id, note_id, **kwargs)


    def delete_analysis_tag(self, container_id, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str container_id: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.analyses_api.delete_analysis_tag(container_id, value, **kwargs)


    def download_input_from_analysis(self, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: input filename (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.analyses_api.download_input_from_analysis(analysis_id, filename, dest_file, **kwargs)


    def get_analysis_input_zip_info(self, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: input filename (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.analyses_api.get_analysis_input_zip_info(analysis_id, filename, **kwargs)


    def get_analysis_input_download_url(self, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: input filename (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.analyses_api.get_analysis_input_download_ticket(analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_analysis(self, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Get Output File

        Get Output File

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: output file name (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.analyses_api.download_output_from_analysis(analysis_id, filename, dest_file, **kwargs)


    def get_analysis_output_zip_info(self, analysis_id, filename, **kwargs):  # noqa: E501
        """Get Output File

        Get Output File

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: output file name (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.analyses_api.get_analysis_output_zip_info(analysis_id, filename, **kwargs)


    def get_analysis_output_download_url(self, analysis_id, filename, **kwargs):  # noqa: E501
        """Get Output File

        Get Output File

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: output file name (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.analyses_api.get_analysis_output_download_ticket(analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_all_analyses(self, **kwargs):  # noqa: E501
        """Find all analyses

        Returns a page of analyses  Args:     filter (t.Optional[str]):     The filters to apply     sort (t.List[Tuple[str,int]): Sorting, as a list of (str, int) tuples     limit (t.Optional[int]):      The maximum number of entries to return     skip (t.Optional[int]):       The number of entries to skip     page (t.Optional[int]):       Page number     after_id (t.Optional[str]):   Id to return results after  Returns:     Page: if a above argument is not None

        :param bool inflate_job: Return job as an object instead of an id
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[union[AnalysisListOutput,AnalysisListOutputInflatedJob]]]
        """
        return self.analyses_api.get_all_analyses(**kwargs)


    def get_analyses(self, container_name, container_id, subcontainer_name, **kwargs):  # noqa: E501
        """Get nested analyses for a container

        Returns analyses that belong to containers of the specified type that belong to ContainerId.  Ex: `projects/{ProjectId}/acquisitions/analyses` will return any analyses that have an acquisition that is under that project as a parent. The `all` keyword is also supported, for example: projects/{ProjectId}/all/analyses will return any analyses that have any session or acquisition or the project itself as a parent. 

        :param str container_name: The parent container type (required)
        :param str container_id: The parent container id (required)
        :param str subcontainer_name: The sub container type (required)
        :param bool async_: Perform the request asynchronously
        :return: list[AnalysisListOutput]
        """
        return self.analyses_api.get_analyses(container_name, container_id, subcontainer_name, **kwargs)


    def get_analysis(self, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.

        Get an analysis by its id

        :param str analysis_id: 24-char hex analysis id (required)
        :param bool inflate_job: expand job info
        :param bool join_avatars: add name and avatar to notes
        :param JoinType join:
        :param bool async_: Perform the request asynchronously
        :return: union[AnalysisOutput,AnalysisOutputInflatedJob]
        """
        return self.analyses_api.get_analysis(analysis_id, **kwargs)


    def get_analysis_file_info(self, container_id, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str container_id: Container id (required)
        :param str filename: The name of the file (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.analyses_api.get_analysis_file_info(container_id, filename, **kwargs)


    def get_analysis_note(self, container_id, note_id, **kwargs):  # noqa: E501
        """Get a note on analysis.

        Get a note on analysis

        :param str container_id: Container id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.analyses_api.get_analysis_note(container_id, note_id, **kwargs)


    def get_analysis_tag(self, container_id, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str container_id: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.analyses_api.get_analysis_tag(container_id, value, **kwargs)


    def modify_analysis(self, analysis_id, body, **kwargs):  # noqa: E501
        """Modify an analysis.

        Modify an analysis by its id  Args:     analysis_id: The id of the analysis     analysis_modify: The modifications to make     auth_session: The auth session

        :param str analysis_id: 24-char hex analysis id (required)
        :param AnalysisModifyInput body: new analysis fields (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.analyses_api.modify_analysis(analysis_id, body, **kwargs)


    def modify_analysis_info(self, container_id, body, **kwargs):  # noqa: E501
        """Update or replace info for a analysis.

        Update or replace info for a analysis.

        :param str container_id: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.analyses_api.modify_analysis_info(container_id, body, **kwargs)


    def modify_analysis_note(self, container_id, note_id, body, **kwargs):  # noqa: E501
        """Update a note on analysis.

        Update a note on analysis

        :param str container_id: Container id (required)
        :param str note_id: 24-char hex note id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.analyses_api.modify_analysis_note(container_id, note_id, body, **kwargs)


    def rename_analysis_tag(self, container_id, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str container_id: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.analyses_api.rename_analysis_tag(container_id, value, body, **kwargs)


    def upload_output_to_analysis(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload an output file to analysis.

        Upload an output file to analysis

        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param str ticket:
        :param bool preserve_metadata:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        if signed:
            signed_result = self.signed_upload_output_to_analysis(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.analyses_api.upload_output_to_analysis(container_id, file, **kwargs)


    def add_audit_trail_report(self, body, **kwargs):  # noqa: E501
        """Starts generation of an Audit Trail Report

        Start generation of a new Audit Trail Report.

        :param CreateReportInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: AuditTrailReport
        """
        return self.audit_trail_api.add_audit_trail_report(body, **kwargs)


    def delete_audit_trail_report(self, report_id, **kwargs):  # noqa: E501
        """Deletes an Audit Trail Report

        Delete an Audit Trail Report

        :param str report_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.audit_trail_api.delete_audit_trail_report(report_id, **kwargs)


    def download_audit_trail_report(self, report_id, **kwargs):  # noqa: E501
        """Download Audit Trail Report

        Download Audit Trail Reports

        :param str report_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.audit_trail_api.download_audit_trail_report(report_id, **kwargs)


    def list_audit_trail_reports(self, **kwargs):  # noqa: E501
        """List Audit Trail Reports

        List Audit Trail Reports.

        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[AuditTrailReport]]
        """
        return self.audit_trail_api.list_audit_trail_reports(**kwargs)


    def modify_audit_trail_report(self, report_id, body, **kwargs):  # noqa: E501
        """Modify an Audit Trail Report

        Modify an Audit Trail Report

        :param str report_id: (required)
        :param ModifyReportInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: AuditTrailReport
        """
        return self.audit_trail_api.modify_audit_trail_report(report_id, body, **kwargs)


    def get_auth_status(self, **kwargs):  # noqa: E501
        """Get Login status

        Get the current login status of the requestor

        :param bool async_: Perform the request asynchronously
        :return: AuthSessionOutput
        """
        return self.auth_api.get_auth_status(**kwargs)


    def cancel_batch(self, batch_id, **kwargs):  # noqa: E501
        """Cancel a Job

        Cancels jobs that are still pending, returns number of jobs cancelled. Moves a 'running' batch job to 'cancelled'.

        :param str batch_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: CancelledBatchOutput
        """
        return self.batch_api.cancel_batch(batch_id, **kwargs)


    def create_batch_job_from_jobs(self, body, **kwargs):  # noqa: E501
        """Create a batch job proposal from preconstructed jobs and insert it as &#x27;pending&#x27;.

        Create a batch job proposal from preconstructed jobs and insert it as 'pending'.

        :param PremadeJobsBatchProposalInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: PremadeJobsBatchProposal
        """
        return self.batch_api.create_batch_job_from_jobs(body, **kwargs)


    def get_all_batches(self, **kwargs):  # noqa: E501
        """Get a list of batch jobs the user has created.

        Requires login.

        :param bool async_: Perform the request asynchronously
        :return: list[Batch]
        """
        return self.batch_api.get_all_batches(**kwargs)


    def get_batch(self, batch_id, **kwargs):  # noqa: E501
        """Get batch job details.


        :param str batch_id: (required)
        :param bool jobs: If true, return job objects instead of job ids
        :param bool async_: Perform the request asynchronously
        :return: union[ClassicBatchJobOutput,ClassicBatchJobOutputInflatedJobs,PremadeJobsBatchJobOutput,PremadeJobsBatchJobOutputInflatedJobs]
        """
        return self.batch_api.get_batch(batch_id, **kwargs)


    def propose_batch(self, body, **kwargs):  # noqa: E501
        """Create a batch job proposal and insert it as &#x27;pending&#x27;.

        Create a batch job proposal and insert it as 'pending'.

        :param ClassicBatchProposalInput body: The batch proposal (required)
        :param bool async_: Perform the request asynchronously
        :return: ClassicBatchProposalOutput
        """
        return self.batch_api.propose_batch(body, **kwargs)


    def start_batch(self, batch_id, **kwargs):  # noqa: E501
        """Launch a job.

        Creates jobs from proposed inputs, returns jobs enqueued. Moves 'pending' batch job to 'running'.

        :param str batch_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[JobOutput]
        """
        return self.batch_api.start_batch(batch_id, **kwargs)


    def bulk_move_sessions(self, body, **kwargs):  # noqa: E501
        """Perform a bulk move of sessions to either a subject or project


        :param BulkMoveInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[MoveConflict]
        """
        return self.bulk_api.bulk_move_sessions(body, **kwargs)


    def get_change_log(self, container_type, container_id, **kwargs):  # noqa: E501
        """Get Change Log


        :param ChangeLogContainerType container_type: (required)
        :param str container_id: (required)
        :param int version: Optional version if retrieving logs for file
        :param bool async_: Perform the request asynchronously
        :return: ChangeLogDocument
        """
        return self.change_log_api.get_change_log(container_type, container_id, **kwargs)


    def get_field_change_log(self, container_type, container_id, field, **kwargs):  # noqa: E501
        """Get change logs by specific field, in reverse chronological order


        :param ChangeLogContainerType container_type: (required)
        :param str container_id: (required)
        :param str field: (required)
        :param int version: Optional version if retrieving logs for file
        :param bool async_: Perform the request asynchronously
        :return: FieldChangeLogDocument
        """
        return self.change_log_api.get_field_change_log(container_type, container_id, field, **kwargs)


    def add_collection(self, body, **kwargs):  # noqa: E501
        """Create a collection

        Create a collection

        :param CollectionInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.collections_api.add_collection(body, **kwargs)


    def add_collection_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to collection.


        :param str container_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.collections_api.add_collection_note(container_id, body, **kwargs)


    def add_collection_permission(self, collection_id, body, **kwargs):  # noqa: E501
        """Add a permission

        Add a permission

        :param str collection_id: (required)
        :param AccessPermission body: (required)
        :param bool async_: Perform the request asynchronously
        :return: AccessPermissionOutput
        """
        return self.collections_api.add_collection_permission(collection_id, body, **kwargs)


    def add_collection_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to collection.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.add_collection_tag(cid, body, **kwargs)


    def add_collection_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to collection

        Add multiple tags to collection

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.add_collection_tags(cid, body, **kwargs)


    def delete_collection(self, collection_id, **kwargs):  # noqa: E501
        """Delete a collection

        Delete Collections.

        :param str collection_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.collections_api.delete_collection(collection_id, **kwargs)


    def delete_collection_file(self, cid, filename, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str cid: (required)
        :param str filename: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.collections_api.delete_collection_file(cid, filename, **kwargs)


    def delete_collection_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Remove a note from collection

        Remove a note from collection

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.collections_api.delete_collection_note(cid, note_id, **kwargs)


    def delete_collection_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.collections_api.delete_collection_tag(cid, value, **kwargs)


    def delete_collection_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete multiple tags from collection

        Delete multiple tags from collection

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.delete_collection_tags(cid, body, **kwargs)


    def delete_collection_user_permission(self, collection_id, user_id, **kwargs):  # noqa: E501
        """Delete a permission

        Delete a permission

        :param str collection_id: (required)
        :param str user_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.delete_collection_user_permission(collection_id, user_id, **kwargs)


    def download_file_from_collection(self, collection_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str collection_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.collections_api.download_file_from_collection(collection_id, file_name, dest_file, **kwargs)


    def get_collection_file_zip_info(self, collection_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str collection_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.collections_api.get_collection_file_zip_info(collection_id, file_name, **kwargs)


    def get_collection_download_url(self, collection_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str collection_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.collections_api.get_collection_download_ticket(collection_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_all_collections(self, **kwargs):  # noqa: E501
        """List all collections.

        List all collections.

        :param bool exhaustive:
        :param bool join_avatars: add name and avatar to notes
        :param bool join_files:
        :param JoinType join:
        :param bool stats:
        :param str user_id:
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[CollectionWithStats],list[CollectionOutput]]
        """
        return self.collections_api.get_all_collections(**kwargs)


    def get_all_collections_curators(self, **kwargs):  # noqa: E501
        """List all curators of collections

        List all curators of collections

        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool async_: Perform the request asynchronously
        :return: list[Curator]
        """
        return self.collections_api.get_all_collections_curators(**kwargs)


    def get_collection(self, collection_id, **kwargs):  # noqa: E501
        """Retrieve a single collection

        Retrieve a single collection

        :param str collection_id: (required)
        :param bool join_avatars: add name and avatar to notes
        :param JoinType join:
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: CollectionOutput
        """
        return self.collections_api.get_collection(collection_id, **kwargs)


    def get_collection_acquisitions(self, collection_id, **kwargs):  # noqa: E501
        """List acquisitions in a collection

        List acquisitions in a collection

        :param str collection_id: (required)
        :param str session: The id of a session, to which the acquisitions returned will be restricted
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[AcquisitionListOutput],Page]
        """
        return self.collections_api.get_collection_acquisitions(collection_id, **kwargs)


    def get_collection_file_info(self, cid, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str cid: (required)
        :param str filename: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.collections_api.get_collection_file_info(cid, filename, **kwargs)


    def get_collection_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Get a note on collection.

        Get a note on collection

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.collections_api.get_collection_note(cid, note_id, **kwargs)


    def get_collection_sessions(self, collection_id, **kwargs):  # noqa: E501
        """List sessions in a collection

        List sessions in a collection.

        :param str collection_id: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[SessionListOutput],Page]
        """
        return self.collections_api.get_collection_sessions(collection_id, **kwargs)


    def get_collection_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.collections_api.get_collection_tag(cid, value, **kwargs)


    def get_collection_user_permission(self, collection_id, user_id, **kwargs):  # noqa: E501
        """List a user&#x27;s permissions for this group.

        List a user's permissions for this group

        :param str collection_id: (required)
        :param str user_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: AccessPermissionOutput
        """
        return self.collections_api.get_collection_user_permission(collection_id, user_id, **kwargs)


    def modify_collection(self, collection_id, body, **kwargs):  # noqa: E501
        """Update a collection and its contents

        Update a collection and its contents

        :param str collection_id: (required)
        :param CollectionInputWithContents body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.modify_collection(collection_id, body, **kwargs)


    def modify_collection_file(self, cid, filename, body, **kwargs):  # noqa: E501
        """Modify a file&#x27;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list)

        :param str cid: (required)
        :param str filename: (required)
        :param FileModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.modify_collection_file(cid, filename, body, **kwargs)


    def modify_collection_file_classification(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.modify_collection_file_classification(cid, filename, body, **kwargs)


    def modify_collection_file_info(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update info for a particular file.

        Modify and return the file 'info' field

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.modify_collection_file_info(cid, filename, body, **kwargs)


    def modify_collection_info(self, cid, body, **kwargs):  # noqa: E501
        """Update or replace info for a collection.

        Update or replace info for a collection.

        :param str cid: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.collections_api.modify_collection_info(cid, body, **kwargs)


    def modify_collection_note(self, cid, note_id, body, **kwargs):  # noqa: E501
        """Update a note on collection.

        Update a note on collection

        :param str cid: (required)
        :param str note_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.collections_api.modify_collection_note(cid, note_id, body, **kwargs)


    def modify_collection_user_permission(self, collection_id, user_id, body, **kwargs):  # noqa: E501
        """Update a user&#x27;s permission for this group.

        Update a users permission for this group

        :param str collection_id: (required)
        :param str user_id: (required)
        :param AccessPermissionUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: AccessPermissionOutput
        """
        return self.collections_api.modify_collection_user_permission(collection_id, user_id, body, **kwargs)


    def rename_collection_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.collections_api.rename_collection_tag(cid, value, body, **kwargs)


    def upload_file_to_collection(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload a file to collection.


        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param bool preserve_metadata:
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str metadata: Metadata object as a JSON-encoded string
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[FileOutput],UploadTicketOutput]
        """
        if signed:
            signed_result = self.signed_upload_file_to_collection(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.collections_api.upload_file_to_collection(container_id, file, **kwargs)


    def get_config(self, **kwargs):  # noqa: E501
        """Get public configuration

        return config dict

        :param bool async_: Perform the request asynchronously
        :return: ConfigOut
        """
        return self.config_api.get_config(**kwargs)


    def get_config_js(self, **kwargs):  # noqa: E501
        """Return public Scitran configuration information in javascript format.

        return config as a JavaScript string assignment

        :param bool async_: Perform the request asynchronously
        :return: object
        """
        return self.config_api.get_config_js(**kwargs)


    def get_version(self, **kwargs):  # noqa: E501
        """Get server and database schema version info

        return database version dict

        :param bool async_: Perform the request asynchronously
        :return: Version
        """
        return self.config_api.get_version(**kwargs)


    def add_container_analysis(self, cid, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis.

        :param str cid: (required)
        :param union[AdhocAnalysisInput,JobAnalysisInput] body: (required)
        :param bool job: returns job_id instead of analysis.id
        :param bool job: returns job_id instead of analysis.id
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.containers_api.add_container_analysis(cid, body, **kwargs)


    def add_container_analysis_note(self, container_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to container analysis.


        :param str container_id: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.containers_api.add_container_analysis_note(container_id, analysis_id, body, **kwargs)


    def add_container_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to container.


        :param str container_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.containers_api.add_container_note(container_id, body, **kwargs)


    def add_container_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to container.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.add_container_tag(cid, body, **kwargs)


    def add_container_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to container

        Add multiple tags to container

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.containers_api.add_container_tags(cid, body, **kwargs)


    def add_view(self, container_id, body, **kwargs):  # noqa: E501
        """Add a new data view

        Create container view

        :param str container_id: (required)
        :param ContainerIdViewInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ViewIdOutput
        """
        return self.containers_api.add_view(container_id, body, **kwargs)


    def delete_container(self, container_id, **kwargs):  # noqa: E501
        """Delete a container

        Delete Container

        :param str container_id: (required)
        :param ContainerDeleteReason delete_reason:
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.containers_api.delete_container(container_id, **kwargs)


    def delete_container_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis

        Delete an analysis for a container.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param ContainerDeleteReason delete_reason: Provide a reason for the deletion
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.containers_api.delete_container_analysis(cid, analysis_id, **kwargs)


    def delete_container_analysis_note(self, cid, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from container analysis.

        Remove a note from container analysis.

        :param str cid: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.containers_api.delete_container_analysis_note(cid, analysis_id, note_id, **kwargs)


    def delete_container_file(self, cid, filename, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str cid: (required)
        :param str filename: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.containers_api.delete_container_file(cid, filename, **kwargs)


    def delete_container_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Remove a note from container

        Remove a note from container

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.containers_api.delete_container_note(cid, note_id, **kwargs)


    def delete_container_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.containers_api.delete_container_tag(cid, value, **kwargs)


    def delete_container_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete multiple tags from container

        Delete multiple tags from container

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.containers_api.delete_container_tags(cid, body, **kwargs)


    def download_file_from_container(self, container_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str container_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.containers_api.download_file_from_container(container_id, file_name, dest_file, **kwargs)


    def get_container_file_zip_info(self, container_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str container_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.containers_api.get_container_file_zip_info(container_id, file_name, **kwargs)


    def get_container_download_url(self, container_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str container_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.containers_api.get_container_download_ticket(container_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_container_analysis(self, container_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.containers_api.download_input_from_container_analysis(container_id, analysis_id, filename, dest_file, **kwargs)


    def get_container_analysis_input_zip_info(self, container_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.containers_api.get_container_analysis_input_zip_info(container_id, analysis_id, filename, **kwargs)


    def get_container_analysis_input_download_url(self, container_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.containers_api.get_container_analysis_input_download_ticket(container_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_container_analysis(self, container_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.containers_api.download_output_from_container_analysis(container_id, analysis_id, filename, dest_file, **kwargs)


    def get_container_analysis_output_zip_info(self, container_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.containers_api.get_container_analysis_output_zip_info(container_id, analysis_id, filename, **kwargs)


    def get_container_analysis_output_download_url(self, container_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.containers_api.get_container_analysis_output_download_ticket(container_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_container(self, container_id, **kwargs):  # noqa: E501
        """Retrieve a single container

        Find Container by ID

        :param str container_id: (required)
        :param JoinType join:
        :param bool join_avatars:
        :param bool async_: Perform the request asynchronously
        :return: union[GroupContainerOutput,ProjectContainerOutput,SubjectContainerOutput,SessionContainerOutput,AcquisitionContainerOutput,AnalysisContainerOutput,CollectionContainerOutput]
        """
        return self.containers_api.get_container(container_id, **kwargs)


    def get_container_analyses(self, cid, **kwargs):  # noqa: E501
        """Get analyses for container.

        Returns analyses that directly belong to this resource.

        :param str cid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool inflate_job:
        :param bool join_avatars:
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[union[AnalysisListOutput,AnalysisListOutputInflatedJob]]]
        """
        return self.containers_api.get_container_analyses(cid, **kwargs)


    def get_container_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.

        Get an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool join_avatars:
        :param JoinType join:
        :param bool async_: Perform the request asynchronously
        :return: union[AnalysisOutputInflatedJob,AnalysisOutput]
        """
        return self.containers_api.get_container_analysis(cid, analysis_id, **kwargs)


    def get_container_file_info(self, cid, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str cid: (required)
        :param str filename: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.containers_api.get_container_file_info(cid, filename, **kwargs)


    def get_container_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Get a note on container.

        Get a note on container

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.containers_api.get_container_note(cid, note_id, **kwargs)


    def get_container_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.containers_api.get_container_tag(cid, value, **kwargs)


    def get_views(self, container_id, **kwargs):  # noqa: E501
        """Return a list of all views belonging to container

        View all containers

        :param str container_id: The ID of the container, one of user, group or project. Use \"site\" as containerId to save or get a site data view. (required)
        :param str filter:
        :param str sort:
        :param int limit:
        :param int skip:
        :param int page:
        :param str after_id:
        :param bool async_: Perform the request asynchronously
        :return: list[ViewOutput]
        """
        return self.containers_api.get_views(container_id, **kwargs)


    def modify_container(self, container_id, body, **kwargs):  # noqa: E501
        """Update a container and its contents

        Modify Container

        :param str container_id: (required)
        :param ContainerUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.modify_container(container_id, body, **kwargs)


    def modify_container_analysis(self, cid, analysis_id, body, **kwargs):  # noqa: E501
        """Modify an analysis.

        Modify an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param AnalysisModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.modify_container_analysis(cid, analysis_id, body, **kwargs)


    def modify_container_file(self, cid, filename, body, **kwargs):  # noqa: E501
        """Modify a file&#x27;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list)

        :param str cid: (required)
        :param str filename: (required)
        :param FileModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.modify_container_file(cid, filename, body, **kwargs)


    def modify_container_file_classification(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.modify_container_file_classification(cid, filename, body, **kwargs)


    def modify_container_file_info(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update info for a particular file.

        Modify and return the file 'info' field

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.modify_container_file_info(cid, filename, body, **kwargs)


    def modify_container_info(self, cid, body, **kwargs):  # noqa: E501
        """Update or replace info for a container.

        Update or replace info for a container.

        :param str cid: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.containers_api.modify_container_info(cid, body, **kwargs)


    def modify_container_note(self, cid, note_id, body, **kwargs):  # noqa: E501
        """Update a note on container.

        Update a note on container

        :param str cid: (required)
        :param str note_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.containers_api.modify_container_note(cid, note_id, body, **kwargs)


    def rename_container_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.containers_api.rename_container_tag(cid, value, body, **kwargs)


    def upload_file_to_container(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload a file to container.


        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param bool preserve_metadata:
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str metadata: Metadata object as a JSON-encoded string
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[FileOutput],UploadTicketOutput]
        """
        if signed:
            signed_result = self.signed_upload_file_to_container(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.containers_api.upload_file_to_container(container_id, file, **kwargs)


    def upload_output_to_container_analysis(self, cid, analysis_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload an output file to analysis.

        Upload an output file to analysis

        :param str cid: (required)
        :param str analysis_id: (required)
        :param str file: The file to upload (required)
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: list[FileOutput]
        """
        if signed:
            signed_result = self.signed_upload_output_to_container_analysis(cid, analysis_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.containers_api.upload_output_to_container_analysis(cid, analysis_id, file, **kwargs)


    def delete_view_execution(self, data_view_execution_id, **kwargs):  # noqa: E501
        """Delete a data_view_execution


        :param str data_view_execution_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.data_view_executions_api.delete_view_execution(data_view_execution_id, **kwargs)


    def get_all_data_view_executions(self, **kwargs):  # noqa: E501
        """Get a list of data_view_executions


        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[DataViewExecution]]
        """
        return self.data_view_executions_api.get_all_data_view_executions(**kwargs)


    def get_data_view_execution(self, data_view_execution_id, **kwargs):  # noqa: E501
        """Get a single data_view_execution


        :param str data_view_execution_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DataViewExecution
        """
        return self.data_view_executions_api.get_data_view_execution(data_view_execution_id, **kwargs)


    def get_data_view_execution_data(self, data_view_execution_id, **kwargs):  # noqa: E501
        """Get the data from a data_view_execution


        :param str data_view_execution_id: (required)
        :param str ticket: download ticket id
        :param FileFormat file_format:
        :param str file_name: download ticket filename
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.data_view_executions_api.get_data_view_execution_data(data_view_execution_id, **kwargs)


    def save_data_view_execution(self, data_view_execution_id, **kwargs):  # noqa: E501
        """Save a data_view_execution to a project


        :param str data_view_execution_id: (required)
        :param FileFormat file_format:
        :param bool async_: Perform the request asynchronously
        :return: File
        """
        return self.data_view_executions_api.save_data_view_execution(data_view_execution_id, **kwargs)


    def delete_save_search(self, search_id, **kwargs):  # noqa: E501
        """Delete a saved search


        :param str search_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.dataexplorer_api.delete_save_search(search_id, **kwargs)


    def get_all_saved_searches(self, **kwargs):  # noqa: E501
        """Get Queries


        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool exhaustive: Return all queries, Admin only
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[SaveSearchOutput],SaveSearchPage]
        """
        return self.dataexplorer_api.get_all_saved_searches(**kwargs)


    def get_saved_search(self, sid, **kwargs):  # noqa: E501
        """Return a saved search query


        :param str sid: (required)
        :param bool async_: Perform the request asynchronously
        :return: SaveSearch
        """
        return self.dataexplorer_api.get_saved_search(sid, **kwargs)


    def get_search_query_suggestions(self, body, **kwargs):  # noqa: E501
        """Get suggestions for a structured search query

        Send the search query from the start of the string, and get a set of suggested replacements back. When utilizing a suggestion, the caller should replace the contents from the \"from\" field to the end of the string with the provided \"value\".

        :param StructuredQuery body: (required)
        :param bool async_: Perform the request asynchronously
        :return: StructuredQuerySuggestions
        """
        return self.dataexplorer_api.get_search_query_suggestions(body, **kwargs)


    def get_search_status(self, **kwargs):  # noqa: E501
        """Get the status of search (Mongo Connector)


        :param bool async_: Perform the request asynchronously
        :return: SearchStatus
        """
        return self.dataexplorer_api.get_search_status(**kwargs)


    def parse_search_query(self, body, **kwargs):  # noqa: E501
        """Parse a structured search query

        Validates a search query, returning any parse errors that were encountered. In the future, this endpoint may return the abstract syntax tree or evaluated query.

        :param StructuredQuery body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ParsedQueryResponse
        """
        return self.dataexplorer_api.parse_search_query(body, **kwargs)


    def replace_search(self, sid, body, **kwargs):  # noqa: E501
        """Replace a search query


        :param str sid: (required)
        :param SaveSearchUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: SaveSearch
        """
        return self.dataexplorer_api.replace_search(sid, body, **kwargs)


    def save_search(self, body, **kwargs):  # noqa: E501
        """Save a search query


        :param SaveSearchInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.dataexplorer_api.save_search(body, **kwargs)


    def search(self, body, **kwargs):  # noqa: E501
        """Perform a search query


        :param SearchQuery body: (required)
        :param bool simple: Unwrap result documents into a list.
        :param int size: The maximum number of results to return.
        :param bool facets: Include additional statistics about the search results. Internal use only.
        :param bool csv: Format the response as a CSV file
        :param bool async_: Perform the request asynchronously
        :return: union[list[SearchResponse],object]
        """
        return self.dataexplorer_api.search(body, **kwargs)


    def create_device(self, body, **kwargs):  # noqa: E501
        """Create a new device.

        Will create a new device record together with an api key. Request must be an admin request.

        :param DeviceCreate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressDevice
        """
        return self.devices_api.create_device(body, **kwargs)


    def delete_device(self, device_id, **kwargs):  # noqa: E501
        """Delete a device

        Delete a device

        :param str device_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.devices_api.delete_device(device_id, **kwargs)


    def delete_device_key(self, device_id, key_id, **kwargs):  # noqa: E501
        """Delete Device Key


        :param str device_id: (required)
        :param str key_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.devices_api.delete_device_key(device_id, key_id, **kwargs)


    def get_all_devices(self, **kwargs):  # noqa: E501
        """List all devices.

        Requires login.

        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool join_keys: Return device key. Admins only
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[EgressDevice],EgressDevicePage]
        """
        return self.devices_api.get_all_devices(**kwargs)


    def get_all_devices_status(self, **kwargs):  # noqa: E501
        """Get status for all known devices.

        ok - missing - error - unknown

        :param bool async_: Perform the request asynchronously
        :return: dict(str, DeviceStatusEntry)
        """
        return self.devices_api.get_all_devices_status(**kwargs)


    def get_current_device(self, **kwargs):  # noqa: E501
        """Get current device.

        Get current device.

        :param bool async_: Perform the request asynchronously
        :return: EgressDevice
        """
        return self.devices_api.get_current_device(**kwargs)


    def get_device(self, device_id, **kwargs):  # noqa: E501
        """Get device details


        :param str device_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressDevice
        """
        return self.devices_api.get_device(device_id, **kwargs)


    def modify_device(self, device_id, body, **kwargs):  # noqa: E501
        """Update a device

        Update a device

        :param str device_id: (required)
        :param DeviceAdminUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressDevice
        """
        return self.devices_api.modify_device(device_id, body, **kwargs)


    def regenerate_key(self, device_id, **kwargs):  # noqa: E501
        """Regenerate device API key

        Regenerate device API key

        :param str device_id: (required)
        :param ApiKeyInputWithOptionalLabel body:
        :param bool async_: Perform the request asynchronously
        :return: object
        """
        return self.devices_api.regenerate_key(device_id, **kwargs)


    def update_device(self, body, **kwargs):  # noqa: E501
        """Modify a device&#x27;s type, name, interval, info or set errors.

        Will modify the device record of the device making the request. Type may only be set once if not already specified at creation. Request must be a drone request.

        :param DeviceSelfUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressDevice
        """
        return self.devices_api.update_device(body, **kwargs)


    def create_project_aet(self, body, **kwargs):  # noqa: E501
        """Create a new DIMSE project AET

        Will create a new DIMSE AET that refers to a Flywheel project. AETs can only be created by admins and use drone access via DIMSE.

        :param ProjectAETInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: BaseAET
        """
        return self.dimse_api.create_project_aet(body, **kwargs)


    def create_service_aet(self, body, **kwargs):  # noqa: E501
        """Create a new DIMSE service AET

        Will create a new DIMSE AET that refers to an external DICOM node. Service AETs can be used to issue C-MOVEs to from project AETs. Requires login. AETs can only be created by admins.

        :param union[ProjectAETInput,ServiceAETInput] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ServiceAET
        """
        return self.dimse_api.create_service_aet(body, **kwargs)


    def delete_project_aet(self, project_aet, **kwargs):  # noqa: E501
        """Delete a DIMSE project AET

        Delete DIMSE project by AET. AETs can only be deleted by admins.

        :param str project_aet: (required)
        :param bool async_: Perform the request asynchronously
        :return: dict(str, int)
        """
        return self.dimse_api.delete_project_aet(project_aet, **kwargs)


    def delete_service_aet(self, service_aet, **kwargs):  # noqa: E501
        """Delete a DIMSE service AET

        Delete DIMSE service by AET. AETs can only be deleted by admins.

        :param str service_aet: (required)
        :param bool async_: Perform the request asynchronously
        :return: dict(str, int)
        """
        return self.dimse_api.delete_service_aet(service_aet, **kwargs)


    def get_all_project_aets(self, **kwargs):  # noqa: E501
        """List all DIMSE project AETs

        Will list all DIMSE AETs referring to a Flywheel project. Project AETs can be used to issue C-FIND and C-MOVE on Flywheel projects. Requires login and admin privilege.

        :param bool async_: Perform the request asynchronously
        :return: list[ProjectAET]
        """
        return self.dimse_api.get_all_project_aets(**kwargs)


    def get_all_service_aets(self, **kwargs):  # noqa: E501
        """List all DIMSE services AETs

        Will list all DIMSE AETs referring to external DICOM nodes. Requires login and admin privilege.

        :param bool async_: Perform the request asynchronously
        :return: list[ServiceAET]
        """
        return self.dimse_api.get_all_service_aets(**kwargs)


    def get_project_aet(self, project_aet, **kwargs):  # noqa: E501
        """Get DIMSE project AET

        Get DIMSE project by AET, id or project id. Requires admin privilege.

        :param str project_aet: (required)
        :param bool async_: Perform the request asynchronously
        :return: ProjectAET
        """
        return self.dimse_api.get_project_aet(project_aet, **kwargs)


    def get_service_aet(self, service_aet, **kwargs):  # noqa: E501
        """Get DIMSE service by AET or id

        Get a DIMSE service. Requires login and admin privilege.

        :param str service_aet: (required)
        :param bool async_: Perform the request asynchronously
        :return: ServiceAET
        """
        return self.dimse_api.get_service_aet(service_aet, **kwargs)


    def create_download_ticket(self, body, **kwargs):  # noqa: E501
        """Create a download ticket

        Use filters in the payload to exclude/include files. To pass a single filter, each of its conditions should be satisfied. If a file pass at least one filter, it is included in the targets.

        :param DownloadInput body: Specification for the download to be performed (required)
        :param DownloadStrategy type: The download type, one of: bulk, classic or full. Default is classic.
        :param bool bulk:
        :param bool metadata: For \"full\" download, whether or not to include metadata sidecars. Default is false.
        :param bool analyses: For \"full\" download, whether or not to include analyses. Default is false.
        :param str prefix: A string to customize the name of the download in the format <prefix>_<timestamp>.tar. Defaults to \"scitran\".
        :param bool async_: Perform the request asynchronously
        :return: DownloadTicketStub
        """
        return self.download_api.create_download_ticket(body, **kwargs)


    def download_ticket(self, ticket, dest_file, **kwargs):  # noqa: E501
        """Download files listed in the given ticket.

        You can use POST to create a download ticket The files listed in the ticket are put into a tar archive

        :param str ticket: ID of the download ticket (required)
        :param DownloadFormat format:
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.download_api.download_ticket(ticket, dest_file, **kwargs)


    def add_file_tags(self, file_id, body, **kwargs):  # noqa: E501
        """Add list of tags on a file.

        Add the tags on a file to the list of tags

        :param str file_id: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[str]
        """
        return self.files_api.add_file_tags(file_id, body, **kwargs)


    def delete_file(self, file_id, **kwargs):  # noqa: E501
        """Delete a File

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str file_id: (required)
        :param int version: Version of the file to delete (defaults to current version)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.files_api.delete_file(file_id, **kwargs)


    def delete_file_tags(self, file_id, **kwargs):  # noqa: E501
        """Remove the specified tags from most recent file version

        Remove the specified tags from most recent file version

        :param str file_id: (required)
        :param list[str] body: List of application-specific tags
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.files_api.delete_file_tags(file_id, **kwargs)


    def get_all_files(self, **kwargs):  # noqa: E501
        """Return all files

        Get metadata of all current user files

        :param str filter:
        :param str sort:
        :param int limit:
        :param int skip:
        :param int page:
        :param str after_id:
        :param bool async_: Perform the request asynchronously
        :return: PageFileOutput_
        """
        return self.files_api.get_all_files(**kwargs)


    def get_file(self, file_id, **kwargs):  # noqa: E501
        """Get File

        Get file details

        :param str file_id: (required)
        :param int version:
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.files_api.get_file(file_id, **kwargs)


    def get_file_tags(self, file_id, **kwargs):  # noqa: E501
        """Return a file tags, from any version

        Return a file tags, from any version

        :param str file_id: (required)
        :param int version:
        :param bool async_: Perform the request asynchronously
        :return: list[str]
        """
        return self.files_api.get_file_tags(file_id, **kwargs)


    def get_file_versions(self, file_id, **kwargs):  # noqa: E501
        """Get Versions

        Get file version details

        :param str file_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[FileVersionOutput]
        """
        return self.files_api.get_file_versions(file_id, **kwargs)


    def move_file(self, file_id, body, **kwargs):  # noqa: E501
        """Move and/or rename a file

        Move a file to a new container and/or give it a new name

        :param str file_id: (required)
        :param FileMoveInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.files_api.move_file(file_id, body, **kwargs)


    def restore_file(self, file_id, version, evaluate_gear_rules, **kwargs):  # noqa: E501
        """Restore a File

        Restore a specific version of a file as the active version. This will create a new version which will be identical to the restored version.

        :param str file_id: (required)
        :param int version: (required)
        :param bool evaluate_gear_rules: Specify if gear rules should be reevaluated on the newly created file version (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.files_api.restore_file(file_id, version, evaluate_gear_rules, **kwargs)


    def set_file_tags(self, file_id, body, **kwargs):  # noqa: E501
        """Set list of tags on a file.

        Set the tags on a file to the list of tags provided

        :param str file_id: (required)
        :param list[str] body: List of application-specific tags (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.files_api.set_file_tags(file_id, body, **kwargs)


    def upsert_file(self, body, **kwargs):  # noqa: E501
        """Upsert a File

        Create or update a file

        :param FileUpsertInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileUpsertOutput
        """
        return self.files_api.upsert_file(body, **kwargs)


    def add_gear(self, gear_name, body, **kwargs):  # noqa: E501
        """Create or update a gear.

        If no existing gear is found, one will be created Otherwise, the specified gear will be updated

        :param str gear_name: Name of the gear to interact with (required)
        :param GearDocumentLegacyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearIdOutput
        """
        return self.gears_api.add_gear(gear_name, body, **kwargs)


    def add_gear_permission(self, gear_name, permission_type, body, **kwargs):  # noqa: E501
        """Add an individual permission to the given gear


        :param str gear_name: Name of the gear to interact with (required)
        :param GearPermissionsType permission_type: (required)
        :param GearPermissionsInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearSeries
        """
        return self.gears_api.add_gear_permission(gear_name, permission_type, body, **kwargs)


    def delete_gear(self, gear_id, **kwargs):  # noqa: E501
        """Delete a gear (not recommended)


        :param str gear_id: Id of the gear to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.gears_api.delete_gear(gear_id, **kwargs)


    def delete_gear_permission(self, gear_name, permission_type, permission_id, **kwargs):  # noqa: E501
        """Delete an individual permission of the given gear


        :param str gear_name: (required)
        :param GearPermissionsType permission_type: (required)
        :param str permission_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.gears_api.delete_gear_permission(gear_name, permission_type, permission_id, **kwargs)


    def delete_gear_permissions(self, gear_name, **kwargs):  # noqa: E501
        """Delete permissions of the given gear


        :param str gear_name: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.gears_api.delete_gear_permissions(gear_name, **kwargs)


    def get_all_gears(self, **kwargs):  # noqa: E501
        """List all gears

        List all gears

        :param str project_id:
        :param bool all_versions: return all versions of each gear
        :param bool include_invalid: return gears with the 'invalid' flag set
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[GearDocument],Page]
        """
        return self.gears_api.get_all_gears(**kwargs)


    def get_gear(self, gear_id, **kwargs):  # noqa: E501
        """Retrieve details about a specific gear

        Retrieve details about a specific gear

        :param str gear_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearDocument
        """
        return self.gears_api.get_gear(gear_id, **kwargs)


    def get_gear_context(self, gear_id, container_name, container_id, **kwargs):  # noqa: E501
        """Get context values for the given gear and container.

        Ref: https://github.com/flywheel-io/gears/tree/master/spec#contextual-values

        :param str gear_id: (required)
        :param str container_name: (required)
        :param str container_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: dict(str, union[GearContextValueOutput,GearContextValueOutputUnfound])
        """
        return self.gears_api.get_gear_context(gear_id, container_name, container_id, **kwargs)


    def get_gear_invocation(self, gear_id, **kwargs):  # noqa: E501
        """Get a schema for invoking a gear

        Get a schema for invoking a gear.

        :param str gear_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: object
        """
        return self.gears_api.get_gear_invocation(gear_id, **kwargs)


    def get_gear_series(self, gear_name, **kwargs):  # noqa: E501
        """Get gear series.

        Gets the series for the gear by its name

        :param str gear_name: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearSeries
        """
        return self.gears_api.get_gear_series(gear_name, **kwargs)


    def get_gear_suggest(self, gear_id, container_name, container_id, **kwargs):  # noqa: E501
        """Get files with input suggestions, parent containers, and child containers for the given container.


        :param str gear_id: Id of the gear to interact with (required)
        :param str container_name: Type of the container to interact with (required)
        :param str container_id: Id of the container to interact with (required)
        :param str filter:
        :param str sort:
        :param int limit:
        :param int skip:
        :param int page:
        :param list[str] include: Include only \"children\" or \"files\"
        :param str collection: Get suggestions for a collection
        :param bool async_: Perform the request asynchronously
        :return: GearSuggestionOutput
        """
        return self.gears_api.get_gear_suggest(gear_id, container_name, container_id, **kwargs)


    def get_gear_ticket(self, ticket_id, **kwargs):  # noqa: E501
        """Retrieve a specific gear ticket


        :param str ticket_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearTicket
        """
        return self.gears_api.get_gear_ticket(ticket_id, **kwargs)


    def get_my_gear_tickets(self, **kwargs):  # noqa: E501
        """Retrieve all gear tickets for the current user


        :param bool async_: Perform the request asynchronously
        :return: list[str]
        """
        return self.gears_api.get_my_gear_tickets(**kwargs)


    def modify_gear_series(self, gear_name, body, **kwargs):  # noqa: E501
        """Update a gear series


        :param str gear_name: Name of the gear series to modify (required)
        :param GearSeriesUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearSeries
        """
        return self.gears_api.modify_gear_series(gear_name, body, **kwargs)


    def prepare_add_gear(self, body, **kwargs):  # noqa: E501
        """Prepare a gear upload

        Prepare a gear upload

        :param GearDocumentInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearTicketOutput
        """
        return self.gears_api.prepare_add_gear(body, **kwargs)


    def replace_gear_permissions(self, gear_name, body, **kwargs):  # noqa: E501
        """Replace permissions for the given gear


        :param str gear_name: Name of the gear to interact with (required)
        :param GearPermissions body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearSeries
        """
        return self.gears_api.replace_gear_permissions(gear_name, body, **kwargs)


    def save_gear(self, body, **kwargs):  # noqa: E501
        """Report the result of a gear upload and save the ticket

        Report the result of a gear upload and save the ticket

        :param GearSaveSubmission body: The ticket, repo and pointer (required)
        :param bool async_: Perform the request asynchronously
        :return: GearDocument
        """
        return self.gears_api.save_gear(body, **kwargs)


    def add_group(self, body, **kwargs):  # noqa: E501
        """Add a group

        Create a new group.

        :param GroupInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.groups_api.add_group(body, **kwargs)


    def add_group_permission(self, group_id, body, **kwargs):  # noqa: E501
        """Add a permission

        Adds permission to the group  Args:     group_id: the id of the group     permission: The access permission     auth_session: The auth session of the user  Returns     AccessPermissionOutput: The added permission

        :param str group_id: (required)
        :param AccessPermission body: (required)
        :param bool async_: Perform the request asynchronously
        :return: AccessPermissionOutput
        """
        return self.groups_api.add_group_permission(group_id, body, **kwargs)


    def add_group_permission_template(self, group_id, body, **kwargs):  # noqa: E501
        """Add a permission template

        Add a permission template

        :param str group_id: (required)
        :param RolePermission body: (required)
        :param bool propagate:
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: RolePermissionOutput
        """
        return self.groups_api.add_group_permission_template(group_id, body, **kwargs)


    def add_group_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to group.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.groups_api.add_group_tag(cid, body, **kwargs)


    def add_group_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to group

        Add multiple tags to group

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.groups_api.add_group_tags(cid, body, **kwargs)


    def add_role_to_group(self, group_id, body, **kwargs):  # noqa: E501
        """Add a role to the pool of roles in a group

        Add a group role.

        :param str group_id: (required)
        :param GroupRole body: (required)
        :param bool async_: Perform the request asynchronously
        :return: RoleOutput
        """
        return self.groups_api.add_role_to_group(group_id, body, **kwargs)


    def delete_group(self, group_id, **kwargs):  # noqa: E501
        """Delete group

        Delete a group.

        :param str group_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.groups_api.delete_group(group_id, **kwargs)


    def delete_group_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.groups_api.delete_group_tag(cid, value, **kwargs)


    def delete_group_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete tags

        Delete tags

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.groups_api.delete_group_tags(cid, body, **kwargs)


    def delete_group_user_permission(self, group_id, user_id, **kwargs):  # noqa: E501
        """Delete a permission

        Deletes a permission from the group  Args:     group_id: the id of the group     user_id: The id of the user     auth_session: The auth session of the user

        :param str group_id: (required)
        :param str user_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.groups_api.delete_group_user_permission(group_id, user_id, **kwargs)


    def delete_group_user_permission_template(self, group_id, user_id, **kwargs):  # noqa: E501
        """Delete a permission

        Delete a permission

        :param str group_id: (required)
        :param str user_id: (required)
        :param bool propagate:
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.groups_api.delete_group_user_permission_template(group_id, user_id, **kwargs)


    def get_all_group_roles(self, group_id, **kwargs):  # noqa: E501
        """Get list of group roles

        Gets all group roles

        :param str group_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[RoleOutput]
        """
        return self.groups_api.get_all_group_roles(group_id, **kwargs)


    def get_all_groups(self, **kwargs):  # noqa: E501
        """List all groups

        Find all groups.

        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[GroupOutput]]
        """
        return self.groups_api.get_all_groups(**kwargs)


    def get_group(self, group_id, **kwargs):  # noqa: E501
        """Get group info

        Get a group by ID.

        :param str group_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: GroupOutput
        """
        return self.groups_api.get_group(group_id, **kwargs)


    def get_group_projects(self, group_id, **kwargs):  # noqa: E501
        """Get all projects in a group

        Get projects for a group

        :param str group_id: (required)
        :param bool exhaustive:
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[ProjectListOutput]]
        """
        return self.groups_api.get_group_projects(group_id, **kwargs)


    def get_group_role(self, group_id, role_id, **kwargs):  # noqa: E501
        """Return the role identified by the RoleId

        Get a group role.

        :param str group_id: (required)
        :param str role_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: RoleOutput
        """
        return self.groups_api.get_group_role(group_id, role_id, **kwargs)


    def get_group_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.groups_api.get_group_tag(cid, value, **kwargs)


    def get_group_user_permission(self, group_id, user_id, **kwargs):  # noqa: E501
        """List a user&#x27;s permissions for this group.

        List a user's permissions for this group

        :param str group_id: (required)
        :param str user_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: AccessPermissionOutput
        """
        return self.groups_api.get_group_user_permission(group_id, user_id, **kwargs)


    def get_group_user_permission_template(self, group_id, user_id, **kwargs):  # noqa: E501
        """List a user&#x27;s permissions for this group.

        List a user's permissions for this group.

        :param str group_id: (required)
        :param str user_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: RolePermissionOutput
        """
        return self.groups_api.get_group_user_permission_template(group_id, user_id, **kwargs)


    def modify_group(self, group_id, body, **kwargs):  # noqa: E501
        """Update group

        Modify a group.

        :param str group_id: (required)
        :param GroupUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.groups_api.modify_group(group_id, body, **kwargs)


    def modify_group_user_permission(self, group_id, user_id, body, **kwargs):  # noqa: E501
        """Update a user&#x27;s permission for this group.

        Update a user's permission for this group.

        :param str group_id: (required)
        :param str user_id: (required)
        :param AccessPermissionUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: AccessPermissionOutput
        """
        return self.groups_api.modify_group_user_permission(group_id, user_id, body, **kwargs)


    def modify_group_user_permission_template(self, group_id, user_id, body, **kwargs):  # noqa: E501
        """Update a user&#x27;s permission for this group.

        Update a user's permission for this group.

        :param str group_id: (required)
        :param str user_id: (required)
        :param RolePermissionUpdate body: (required)
        :param bool propagate:
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: RolePermissionOutput
        """
        return self.groups_api.modify_group_user_permission_template(group_id, user_id, body, **kwargs)


    def remove_role_from_group(self, group_id, role_id, **kwargs):  # noqa: E501
        """Remove the role from the group

        Delete a group role.

        :param str group_id: (required)
        :param str role_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.groups_api.remove_role_from_group(group_id, role_id, **kwargs)


    def rename_group_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.groups_api.rename_group_tag(cid, value, body, **kwargs)


    def add_job(self, body, **kwargs):  # noqa: E501
        """Add a job

        Add a job

        :param InputJob body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.jobs_api.add_job(body, **kwargs)


    def add_job_logs(self, job_id, body, **kwargs):  # noqa: E501
        """Add logs to a job.


        :param str job_id: (required)
        :param list[JobLog] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.jobs_api.add_job_logs(job_id, body, **kwargs)


    def ask_jobs(self, body, **kwargs):  # noqa: E501
        """Ask the queue a question

        Ask the queue a question, receiving work or statistics in return.

        :param JobAsk body: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobAskResponse
        """
        return self.jobs_api.ask_jobs(body, **kwargs)


    def ask_jobs_state(self, job_state, body, **kwargs):  # noqa: E501
        """Ask job count by state

        Ask the queue for the number of jobs for a given state and query.

        :param JobState job_state: (required)
        :param JobAsk body: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobAskStateResponse
        """
        return self.jobs_api.ask_jobs_state(job_state, body, **kwargs)


    def complete_job(self, job_id, body, **kwargs):  # noqa: E501
        """Complete a job, with information


        :param str job_id: (required)
        :param JobComplete body: (required)
        :param str job_ticket_id: ticket id for job completion
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.jobs_api.complete_job(job_id, body, **kwargs)


    def determine_provider_for_job(self, body, **kwargs):  # noqa: E501
        """Determine the effective compute provider for a proposed job.


        :param InputJob body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Provider
        """
        return self.jobs_api.determine_provider_for_job(body, **kwargs)


    def get_all_jobs(self, **kwargs):  # noqa: E501
        """Return all jobs


        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool include_parent_info: Include the parent info for the jobs
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[JobListOutput],Page]
        """
        return self.jobs_api.get_all_jobs(**kwargs)


    def get_job(self, job_id, **kwargs):  # noqa: E501
        """Get job details


        :param str job_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobOutput
        """
        return self.jobs_api.get_job(job_id, **kwargs)


    def get_job_config(self, job_id, **kwargs):  # noqa: E501
        """Get a job&#x27;s config


        :param str job_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobOutputConfig
        """
        return self.jobs_api.get_job_config(job_id, **kwargs)


    def get_job_detail(self, job_id, **kwargs):  # noqa: E501
        """Get job container details


        :param str job_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobDetail
        """
        return self.jobs_api.get_job_detail(job_id, **kwargs)


    def get_job_logs(self, job_id, **kwargs):  # noqa: E501
        """Get job logs


        :param str job_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobLogRecord
        """
        return self.jobs_api.get_job_logs(job_id, **kwargs)


    def get_jobs_stats(self, **kwargs):  # noqa: E501
        """Get stats about all current jobs


        :param bool async_: Perform the request asynchronously
        :return: object
        """
        return self.jobs_api.get_jobs_stats(**kwargs)


    def get_next_job(self, **kwargs):  # noqa: E501
        """Get the next job in the queue

        Used by the engine.

        :param list[str] tags:
        :param list[str] tags:
        :param bool async_: Perform the request asynchronously
        :return: Job
        """
        return self.jobs_api.get_next_job(**kwargs)


    def modify_job(self, job_id, body, **kwargs):  # noqa: E501
        """Update a job.

        Updates timestamp. Enforces a valid state machine transition, if any. Rejects any change to a job that is not currently in 'pending' or 'running' state. Accepts the same body as /api/jobs/add, except all fields are optional.

        :param str job_id: (required)
        :param JobModify body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.jobs_api.modify_job(job_id, body, **kwargs)


    def prepare_complete_job(self, job_id, **kwargs):  # noqa: E501
        """Create a ticket for completing a job, with id and status.


        :param str job_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: JobTicketOutput
        """
        return self.jobs_api.prepare_complete_job(job_id, **kwargs)


    def reap_jobs(self, **kwargs):  # noqa: E501
        """Reap stale jobs


        :param bool async_: Perform the request asynchronously
        :return: OrphanedCount
        """
        return self.jobs_api.reap_jobs(**kwargs)


    def retry_job(self, job_id, **kwargs):  # noqa: E501
        """Retry a job.

        The job must have a state of 'failed', and must not have already been retried. The failed jobs config is copied to a new job. The ID of the new job is returned.

        :param str job_id: (required)
        :param str compute_provider_id:
        :param bool ignore_state:
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.jobs_api.retry_job(job_id, **kwargs)


    def update_job_profile(self, job_id, body, **kwargs):  # noqa: E501
        """Update profile information on a job. (e.g. machine type, etc)

        Update profile information on a job. (e.g. machine type, etc)

        :param str job_id: (required)
        :param InputJobProfile body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.jobs_api.update_job_profile(job_id, body, **kwargs)


    def update_jobs_priority(self, body, **kwargs):  # noqa: E501
        """Update a job priority.


        :param JobPriorityUpdate body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.jobs_api.update_jobs_priority(body, **kwargs)


    def get_jupyterlab_server(self, jupyterlab_server_id, **kwargs):  # noqa: E501
        """Get jupyterlab server

        Get jupyterlab server

        :param str jupyterlab_server_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: JupyterlabServerResponse
        """
        return self.jupyterlab_servers_api.get_jupyterlab_server(jupyterlab_server_id, **kwargs)


    def modify_jupyterlab_server(self, jupyterlab_server_id, body, **kwargs):  # noqa: E501
        """Update a jupyterlab server

        Update a jupyterlab server

        :param str jupyterlab_server_id: (required)
        :param JupyterlabServerModify body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.jupyterlab_servers_api.modify_jupyterlab_server(jupyterlab_server_id, body, **kwargs)


    def add_modality(self, body, **kwargs):  # noqa: E501
        """Create a new modality.

        handlers.modalityhandler.ModalityHandler.post

        :param ModalityInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.modalities_api.add_modality(body, **kwargs)


    def delete_modality(self, modality_id, **kwargs):  # noqa: E501
        """Delete a modality


        :param str modality_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.modalities_api.delete_modality(modality_id, **kwargs)


    def get_all_modalities(self, **kwargs):  # noqa: E501
        """List all modalities.

        Requires login.

        :param str filter: The filter to apply. (e.g. description=my-desc,active:true)
        :param str sort: The sort fields and order.(e.g. description:asc,active:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[ModalityOutput],Page]
        """
        return self.modalities_api.get_all_modalities(**kwargs)


    def get_modality(self, modality_id, **kwargs):  # noqa: E501
        """Get a modality&#x27;s classification specification


        :param str modality_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModalityOutput
        """
        return self.modalities_api.get_modality(modality_id, **kwargs)


    def replace_modality(self, modality_id, body, **kwargs):  # noqa: E501
        """Replace modality


        :param str modality_id: (required)
        :param ModalityModify body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModalityOutput
        """
        return self.modalities_api.replace_modality(modality_id, body, **kwargs)


    def clean_packfiles(self, **kwargs):  # noqa: E501
        """Clean up expired upload tokens and invalid token directories.

        Clean up expired upload tokens and invalid token directories.

        :param bool async_: Perform the request asynchronously
        :return: PackfileCleanupOutput
        """
        return self.packfiles_api.clean_packfiles(**kwargs)


    def add_project(self, body, **kwargs):  # noqa: E501
        """Create a new project


        :param ProjectInput body: (required)
        :param bool inherit: Inherit permissions from the group permission template
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.projects_api.add_project(body, **kwargs)


    def add_project_analysis(self, cid, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis.

        :param str cid: (required)
        :param union[AdhocAnalysisInput,JobAnalysisInput] body: (required)
        :param bool job: returns job_id instead of analysis.id
        :param bool job: returns job_id instead of analysis.id
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.projects_api.add_project_analysis(cid, body, **kwargs)


    def add_project_analysis_note(self, container_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to project analysis.


        :param str container_id: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.projects_api.add_project_analysis_note(container_id, analysis_id, body, **kwargs)


    def add_project_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to project.


        :param str container_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.projects_api.add_project_note(container_id, body, **kwargs)


    def add_project_permission(self, project_id, body, **kwargs):  # noqa: E501
        """Add a permission

        Add user to a project  Args:     project_id: The id of the project     permission: The permission to add     auth_session: The auth session  Returns:     RolePermissionOutput: The added permission

        :param str project_id: (required)
        :param RolePermission body: (required)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: RolePermissionOutput
        """
        return self.projects_api.add_project_permission(project_id, body, **kwargs)


    def add_project_rule(self, project_id, body, **kwargs):  # noqa: E501
        """Create a new rule for a project.


        :param str project_id: (required)
        :param GearRuleInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearRuleOutput
        """
        return self.projects_api.add_project_rule(project_id, body, **kwargs)


    def add_project_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to project.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.add_project_tag(cid, body, **kwargs)


    def add_project_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to project

        Add multiple tags to project

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.add_project_tags(cid, body, **kwargs)


    def catalog_list(self, **kwargs):  # noqa: E501
        """Catalog List


        :param str search_string: Include only results containing the search string
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[CatalogListOutput],Page]
        """
        return self.projects_api.catalog_list(**kwargs)


    def delete_project(self, project_id, **kwargs):  # noqa: E501
        """Delete a project

        Only site admins and users with \"admin\" project permissions may delete a project

        :param str project_id: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.delete_project(project_id, **kwargs)


    def delete_project_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis

        Delete an analysis for a container.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param ContainerDeleteReason delete_reason: Provide a reason for the deletion
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.delete_project_analysis(cid, analysis_id, **kwargs)


    def delete_project_analysis_note(self, cid, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from project analysis.

        Remove a note from project analysis.

        :param str cid: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.delete_project_analysis_note(cid, analysis_id, note_id, **kwargs)


    def delete_project_file(self, cid, filename, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str cid: (required)
        :param str filename: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.delete_project_file(cid, filename, **kwargs)


    def delete_project_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Remove a note from project

        Remove a note from project

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.delete_project_note(cid, note_id, **kwargs)


    def delete_project_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.delete_project_tag(cid, value, **kwargs)


    def delete_project_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete multiple tags from project

        Delete multiple tags from project

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.delete_project_tags(cid, body, **kwargs)


    def delete_project_user_permission(self, project_id, uid, **kwargs):  # noqa: E501
        """Delete a permission


        :param str project_id: (required)
        :param str uid: (required)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.delete_project_user_permission(project_id, uid, **kwargs)


    def download_file_from_project(self, project_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str project_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.projects_api.download_file_from_project(project_id, file_name, dest_file, **kwargs)


    def get_project_file_zip_info(self, project_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str project_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.projects_api.get_project_file_zip_info(project_id, file_name, **kwargs)


    def get_project_download_url(self, project_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str project_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.projects_api.get_project_download_ticket(project_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_project_analysis(self, project_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.projects_api.download_input_from_project_analysis(project_id, analysis_id, filename, dest_file, **kwargs)


    def get_project_analysis_input_zip_info(self, project_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.projects_api.get_project_analysis_input_zip_info(project_id, analysis_id, filename, **kwargs)


    def get_project_analysis_input_download_url(self, project_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.projects_api.get_project_analysis_input_download_ticket(project_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_project_analysis(self, project_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.projects_api.download_output_from_project_analysis(project_id, analysis_id, filename, dest_file, **kwargs)


    def get_project_analysis_output_zip_info(self, project_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.projects_api.get_project_analysis_output_zip_info(project_id, analysis_id, filename, **kwargs)


    def get_project_analysis_output_download_url(self, project_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.projects_api.get_project_analysis_output_download_ticket(project_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def end_project_packfile_upload(self, token, metadata, file_count, project_id, **kwargs):  # noqa: E501
        """End a packfile upload


        :param str token: (required)
        :param str metadata: Metadata object as a JSON-encoded string (required)
        :param int file_count: Number of files uploaded into this packfile. (required)
        :param str project_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.end_project_packfile_upload(token, metadata, file_count, project_id, **kwargs)


    def get_all_projects(self, **kwargs):  # noqa: E501
        """Get a list of projects


        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool counts: Append the count of subjects in each project
        :param bool stats: Return the status of subjects and sessions in each project
        :param bool join_avatars: Return the joined avatars of the permissions
        :param JoinType join:
        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[ProjectListOutput],Page]
        """
        return self.projects_api.get_all_projects(**kwargs)


    def get_all_projects_groups(self, **kwargs):  # noqa: E501
        """List all groups which have a project in them


        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool exhaustive: returns exhaustive list if correct permissions
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: list[GroupOutput]
        """
        return self.projects_api.get_all_projects_groups(**kwargs)


    def get_catalog_list_filter_options(self, **kwargs):  # noqa: E501
        """Get all filter options for sharing a project


        :param bool async_: Perform the request asynchronously
        :return: SharingFilterOptions
        """
        return self.projects_api.get_catalog_list_filter_options(**kwargs)


    def get_project(self, project_id, **kwargs):  # noqa: E501
        """Get a single project


        :param str project_id: (required)
        :param JoinType join:
        :param bool join_avatars: add name and avatar to notes
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: ProjectOutput
        """
        return self.projects_api.get_project(project_id, **kwargs)


    def get_project_acquisitions(self, project_id, **kwargs):  # noqa: E501
        """List all acquisitions for the given project.


        :param str project_id: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param str collection_id:
        :param bool exhaustive:
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[AcquisitionListOutput],Page]
        """
        return self.projects_api.get_project_acquisitions(project_id, **kwargs)


    def get_project_analyses(self, cid, **kwargs):  # noqa: E501
        """Get analyses for project.

        Returns analyses that directly belong to this resource.

        :param str cid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool inflate_job:
        :param bool join_avatars:
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[union[AnalysisListOutput,AnalysisListOutputInflatedJob]]]
        """
        return self.projects_api.get_project_analyses(cid, **kwargs)


    def get_project_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.

        Get an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool join_avatars:
        :param JoinType join:
        :param bool async_: Perform the request asynchronously
        :return: union[AnalysisOutputInflatedJob,AnalysisOutput]
        """
        return self.projects_api.get_project_analysis(cid, analysis_id, **kwargs)


    def get_project_file_info(self, cid, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str cid: (required)
        :param str filename: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.projects_api.get_project_file_info(cid, filename, **kwargs)


    def get_project_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Get a note on project.

        Get a note on project

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.projects_api.get_project_note(cid, note_id, **kwargs)


    def get_project_rule(self, project_id, rule_id, **kwargs):  # noqa: E501
        """Get a project rule.

        Get a project rule.

        :param str project_id: (required)
        :param str rule_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearRuleOutput
        """
        return self.projects_api.get_project_rule(project_id, rule_id, **kwargs)


    def get_project_rules(self, project_id, **kwargs):  # noqa: E501
        """List all rules for a project.


        :param str project_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[GearRuleOutput]
        """
        return self.projects_api.get_project_rules(project_id, **kwargs)


    def get_project_sessions(self, project_id, **kwargs):  # noqa: E501
        """List all sessions for the given project.

        Returns a page of sessions by their parent

        :param str project_id: 24-char hex subject id (required)
        :param JoinType join: join file origins
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[SessionListOutput]]
        """
        return self.projects_api.get_project_sessions(project_id, **kwargs)


    def get_project_settings(self, project_id, **kwargs):  # noqa: E501
        """Get settings on project


        :param str project_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: ProjectSettingsOutput
        """
        return self.projects_api.get_project_settings(project_id, **kwargs)


    def get_project_subjects(self, project_id, **kwargs):  # noqa: E501
        """List all subjects for the given project.

        List all subjects for the given project.

        :param str project_id: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[SubjectOutputForList]]
        """
        return self.projects_api.get_project_subjects(project_id, **kwargs)


    def get_project_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.projects_api.get_project_tag(cid, value, **kwargs)


    def get_project_user_permission(self, project_id, uid, **kwargs):  # noqa: E501
        """List a user&#x27;s permissions for this project.

        Get a user's permission from a project  Args:     project_id: The id of the project     uid: The id of the user     auth_session: The auth session  Returns:     RolePermissionOutput: The permission

        :param str project_id: (required)
        :param str uid: (required)
        :param bool async_: Perform the request asynchronously
        :return: RolePermissionOutput
        """
        return self.projects_api.get_project_user_permission(project_id, uid, **kwargs)


    def modify_project(self, project_id, body, **kwargs):  # noqa: E501
        """Update a project


        :param str project_id: (required)
        :param ProjectModify body: (required)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.modify_project(project_id, body, **kwargs)


    def modify_project_analysis(self, cid, analysis_id, body, **kwargs):  # noqa: E501
        """Modify an analysis.

        Modify an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param AnalysisModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.modify_project_analysis(cid, analysis_id, body, **kwargs)


    def modify_project_file(self, cid, filename, body, **kwargs):  # noqa: E501
        """Modify a file&#x27;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list)

        :param str cid: (required)
        :param str filename: (required)
        :param FileModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.modify_project_file(cid, filename, body, **kwargs)


    def modify_project_file_classification(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.modify_project_file_classification(cid, filename, body, **kwargs)


    def modify_project_file_info(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update info for a particular file.

        Modify and return the file 'info' field

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.modify_project_file_info(cid, filename, body, **kwargs)


    def modify_project_info(self, cid, body, **kwargs):  # noqa: E501
        """Update or replace info for a project.

        Update or replace info for a project.

        :param str cid: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.modify_project_info(cid, body, **kwargs)


    def modify_project_note(self, cid, note_id, body, **kwargs):  # noqa: E501
        """Update a note on project.

        Update a note on project

        :param str cid: (required)
        :param str note_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.projects_api.modify_project_note(cid, note_id, body, **kwargs)


    def modify_project_rule(self, project_id, rule_id, body, **kwargs):  # noqa: E501
        """Update a rule on a project.

        Update a rule on a project.

        :param str project_id: (required)
        :param str rule_id: (required)
        :param GearRuleModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearRuleOutput
        """
        return self.projects_api.modify_project_rule(project_id, rule_id, body, **kwargs)


    def modify_project_settings(self, project_id, body, **kwargs):  # noqa: E501
        """Modify project settings


        :param str project_id: (required)
        :param ProjectSettingsInput body: (required)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: ProjectSettingsOutput
        """
        return self.projects_api.modify_project_settings(project_id, body, **kwargs)


    def modify_project_user_permission(self, project_id, uid, body, **kwargs):  # noqa: E501
        """Update a user&#x27;s permission for this project.

        Update a user's permission for this project.

        :param str project_id: (required)
        :param str uid: (required)
        :param RolePermissionUpdate body: (required)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: RolePermissionOutput
        """
        return self.projects_api.modify_project_user_permission(project_id, uid, body, **kwargs)


    def project_copy(self, project_id, body, **kwargs):  # noqa: E501
        """Copy By Reference

        Copy a project and its descendants to a new project tree

        :param str project_id: (required)
        :param ProjectCopyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ProjectCopyOutput
        """
        return self.projects_api.project_copy(project_id, body, **kwargs)


    def project_packfile_upload(self, project_id, token, file, **kwargs):  # noqa: E501
        """Add files to an in-progress packfile


        :param str project_id: (required)
        :param str token: (required)
        :param str file: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[FileOutput]
        """
        return self.projects_api.project_packfile_upload(project_id, token, file, **kwargs)


    def recalc_all_projects(self, **kwargs):  # noqa: E501
        """Recalculate all sessions against their project templates.

        Iterates all projects that have a session template. Recalculate if projects' sessions satisfy the template. Returns list of modified session ids.

        :param bool async_: Perform the request asynchronously
        :return: SessionTemplateRecalcOutput
        """
        return self.projects_api.recalc_all_projects(**kwargs)


    def recalc_project(self, project_id, **kwargs):  # noqa: E501
        """Currently does nothing--will eventually calculate if sessions in the project satisfy the template.

        Currently does nothing--will eventually calculate if sessions in the project satisfy the template.

        :param str project_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: SessionTemplateRecalcOutput
        """
        return self.projects_api.recalc_project(project_id, **kwargs)


    def remove_project_rule(self, project_id, rule_id, **kwargs):  # noqa: E501
        """Remove a project rule.


        :param str project_id: (required)
        :param str rule_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.remove_project_rule(project_id, rule_id, **kwargs)


    def remove_project_template(self, project_id, **kwargs):  # noqa: E501
        """Remove the session template for a project.


        :param str project_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.projects_api.remove_project_template(project_id, **kwargs)


    def rename_project_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.projects_api.rename_project_tag(cid, value, body, **kwargs)


    def set_project_template(self, project_id, body, **kwargs):  # noqa: E501
        """Set the session template for a project.


        :param str project_id: (required)
        :param ProjectTemplateListInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.projects_api.set_project_template(project_id, body, **kwargs)


    def start_project_packfile_upload(self, project_id, **kwargs):  # noqa: E501
        """Start a packfile upload to project


        :param str project_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: UploadTokenOutput
        """
        return self.projects_api.start_project_packfile_upload(project_id, **kwargs)


    def upload_file_to_project(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload a file to project.


        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param bool preserve_metadata:
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str metadata: Metadata object as a JSON-encoded string
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[FileOutput],UploadTicketOutput]
        """
        if signed:
            signed_result = self.signed_upload_file_to_project(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.projects_api.upload_file_to_project(container_id, file, **kwargs)


    def upload_output_to_project_analysis(self, cid, analysis_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload an output file to analysis.

        Upload an output file to analysis

        :param str cid: (required)
        :param str analysis_id: (required)
        :param str file: The file to upload (required)
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: list[FileOutput]
        """
        if signed:
            signed_result = self.signed_upload_output_to_project_analysis(cid, analysis_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.projects_api.upload_output_to_project_analysis(cid, analysis_id, file, **kwargs)


    def upsert_project_hierarchy(self, project_id, body, **kwargs):  # noqa: E501
        """Create or update subject, session and acquisition containers in the project.

        Create, update or just return an existing container sub-hierarchy as-is for the given project. Useful for efficient and highly parallel automated imports using device authN, based on common routing fields such as id, uid and label.

        :param str project_id: (required)
        :param ProjectHierarchyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ProjectHierarchyOutput
        """
        return self.projects_api.upsert_project_hierarchy(project_id, body, **kwargs)


    def collect_usage(self, **kwargs):  # noqa: E501
        """Collect daily usage statistics.

        Collects usage statistics for the selected day (or yesterday if no day is given)

        :param int year: The year portion of the date
        :param int month: The month portion of the date
        :param int day: The day portion of the date
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.reports_api.collect_usage(**kwargs)


    def get_access_log_report(self, **kwargs):  # noqa: E501
        """Get a report of access log entries for the given parameters


        :param bool csv: Set to download a csv file instead of json
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param datetime start_date: An ISO formatted timestamp for the start time of the report
        :param datetime end_date: An ISO formatted timestamp for the end time of the report
        :param str user: User id of the target user
        :param str subject: Limit the report to the subject code of subject accessed
        :param str project: Limit the report to the project id
        :param list[AccessType] access_types: The list of access_types to filter logs
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: list[ReportAccessLogEntry]
        """
        return self.reports_api.get_access_log_report(**kwargs)


    def get_access_log_types(self, **kwargs):  # noqa: E501
        """Get the list of types of access log entries


        :param bool async_: Perform the request asynchronously
        :return: list[str]
        """
        return self.reports_api.get_access_log_types(**kwargs)


    def get_daily_usage_report(self, **kwargs):  # noqa: E501
        """Get a daily usage report for the given month.

        If no year/month pair is given, the current month will be used.

        :param int year: The year portion of the date
        :param int month: The month portion of the date
        :param str group: Limit the report to the given group id
        :param str project: Limit the report to the given project id
        :param bool async_: Perform the request asynchronously
        :return: list[DailyReportUsage]
        """
        return self.reports_api.get_daily_usage_report(**kwargs)


    def get_legacy_usage_report(self, type, **kwargs):  # noqa: E501
        """Get a usage report for the site grouped by month or project

        This report is DEPRECATED and will be removed in a future release

        :param str type: The type of usage report to generate (required)
        :param datetime start_date: An ISO formatted timestamp for the start time of the report
        :param datetime end_date: An ISO formatted timestamp for the end time of the report
        :param bool async_: Perform the request asynchronously
        :return: list[LegacyUsageReport]
        """
        return self.reports_api.get_legacy_usage_report(type, **kwargs)


    def get_project_report(self, **kwargs):  # noqa: E501
        """Get project report

        Get project report

        :param list[str] projects: Specify multiple times to include projects in the report
        :param datetime start_date: Report start date
        :param datetime end_date: Report end date
        :param bool async_: Perform the request asynchronously
        :return: ProjectReportList
        """
        return self.reports_api.get_project_report(**kwargs)


    def get_site_report(self, **kwargs):  # noqa: E501
        """Get the site report


        :param bool async_: Perform the request asynchronously
        :return: SiteReport
        """
        return self.reports_api.get_site_report(**kwargs)


    def get_usage_availability(self, **kwargs):  # noqa: E501
        """Get year/month combinations where report data is available.

        Get year/month combinations where report data is available. Returns:     Returns the list of months where report data is available

        :param bool async_: Perform the request asynchronously
        :return: ReportAvailabilityList
        """
        return self.reports_api.get_usage_availability(**kwargs)


    def get_usage_report(self, **kwargs):  # noqa: E501
        """Get a usage report for the given month.

        If no year/month pair is given, the current month will be used.

        :param int year: The year portion of the date
        :param int month: The month portion of the date
        :param str project: Project to filter to
        :param bool async_: Perform the request asynchronously
        :return: list[ReportUsage]
        """
        return self.reports_api.get_usage_report(**kwargs)


    def lookup_path(self, body, **kwargs):  # noqa: E501
        """Perform path based lookup of a single node in the Flywheel hierarchy

        This will perform a deep lookup of a node. See /resolve for more details.

        :param ResolveInput body: (required)
        :param bool full_tree:
        :param bool exhaustive:
        :param bool async_: Perform the request asynchronously
        :return: ResolverNode
        """
        return self.resolve_api.lookup_path(body, **kwargs)


    def resolve_path(self, body, **kwargs):  # noqa: E501
        """Perform path based lookup of nodes in the Flywheel hierarchy

        This will perform a deep lookup of a node (i.e. group/project/session/acquisition) and its children, including any files. The query path is an array of strings in the following order (by default):    * group id   * project label   * session label   * acquisition label  Additionally, analyses for project/session/acquisition nodes can be resolved by inserting the literal string `\"analyses\"`. e.g. `['scitran', 'MyProject', 'analyses']`.  Files for projects, sessions, acquisitions and analyses can be resolved by inserting the literal string `\"files\"`. e.g. `['scitran', 'MyProject', 'files']`.  An ID can be used instead of a label by formatting the string as `<id:project_id>`. The full path to the node, and the node's children will be included in the response.

        :param ResolveInput body: (required)
        :param bool full_tree: Parse full download style paths (e.g. group/PROJECTS/project_label/SUBJECTS/...)
        :param bool minattr: Return only minimal attributes
        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param bool async_: Perform the request asynchronously
        :return: ResolveOutput
        """
        return self.resolve_api.resolve_path(body, **kwargs)


    def add_role(self, body, **kwargs):  # noqa: E501
        """Add a new role


        :param RoleInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: RoleOutput
        """
        return self.roles_api.add_role(body, **kwargs)


    def delete_role(self, role_id, **kwargs):  # noqa: E501
        """Delete the role


        :param str role_id: The ID of the role (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.roles_api.delete_role(role_id, **kwargs)


    def get_all_roles(self, **kwargs):  # noqa: E501
        """Get list of all roles


        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[RoleOutput],Page]
        """
        return self.roles_api.get_all_roles(**kwargs)


    def get_role(self, role_id, **kwargs):  # noqa: E501
        """Return the role identified by the RoleId


        :param str role_id: The ID of the role (required)
        :param bool async_: Perform the request asynchronously
        :return: RoleOutput
        """
        return self.roles_api.get_role(role_id, **kwargs)


    def modify_role(self, role_id, body, **kwargs):  # noqa: E501
        """Update the role identified by RoleId


        :param str role_id: (required)
        :param RoleUpdate body: (required)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: RoleOutput
        """
        return self.roles_api.modify_role(role_id, body, **kwargs)


    def add_session(self, body, **kwargs):  # noqa: E501
        """Create a new session

        Create a session.

        :param SessionInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.sessions_api.add_session(body, **kwargs)


    def add_session_analysis(self, cid, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis.

        :param str cid: (required)
        :param union[AdhocAnalysisInput,JobAnalysisInput] body: (required)
        :param bool job: returns job_id instead of analysis.id
        :param bool job: returns job_id instead of analysis.id
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.sessions_api.add_session_analysis(cid, body, **kwargs)


    def add_session_analysis_note(self, container_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to session analysis.


        :param str container_id: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.sessions_api.add_session_analysis_note(container_id, analysis_id, body, **kwargs)


    def add_session_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to session.


        :param str container_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.sessions_api.add_session_note(container_id, body, **kwargs)


    def add_session_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to session.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.add_session_tag(cid, body, **kwargs)


    def add_session_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to session

        Add multiple tags to session

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.sessions_api.add_session_tags(cid, body, **kwargs)


    def delete_session(self, session_id, **kwargs):  # noqa: E501
        """Delete a session

        Read-write project permissions are required to delete a session. Admin project permissions are required if the session or it's acquisitions contain data uploaded by sources other than users and jobs.

        :param str session_id: (required)
        :param ContainerDeleteReason delete_reason:
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.sessions_api.delete_session(session_id, **kwargs)


    def delete_session_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis

        Delete an analysis for a container.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param ContainerDeleteReason delete_reason: Provide a reason for the deletion
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.sessions_api.delete_session_analysis(cid, analysis_id, **kwargs)


    def delete_session_analysis_note(self, cid, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from session analysis.

        Remove a note from session analysis.

        :param str cid: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.sessions_api.delete_session_analysis_note(cid, analysis_id, note_id, **kwargs)


    def delete_session_file(self, cid, filename, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str cid: (required)
        :param str filename: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.sessions_api.delete_session_file(cid, filename, **kwargs)


    def delete_session_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Remove a note from session

        Remove a note from session

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.sessions_api.delete_session_note(cid, note_id, **kwargs)


    def delete_session_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.sessions_api.delete_session_tag(cid, value, **kwargs)


    def delete_session_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete multiple tags from session

        Delete multiple tags from session

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.sessions_api.delete_session_tags(cid, body, **kwargs)


    def download_file_from_session(self, session_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str session_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.sessions_api.download_file_from_session(session_id, file_name, dest_file, **kwargs)


    def get_session_file_zip_info(self, session_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str session_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.sessions_api.get_session_file_zip_info(session_id, file_name, **kwargs)


    def get_session_download_url(self, session_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str session_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.sessions_api.get_session_download_ticket(session_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_session_analysis(self, session_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.sessions_api.download_input_from_session_analysis(session_id, analysis_id, filename, dest_file, **kwargs)


    def get_session_analysis_input_zip_info(self, session_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.sessions_api.get_session_analysis_input_zip_info(session_id, analysis_id, filename, **kwargs)


    def get_session_analysis_input_download_url(self, session_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.sessions_api.get_session_analysis_input_download_ticket(session_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_session_analysis(self, session_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.sessions_api.download_output_from_session_analysis(session_id, analysis_id, filename, dest_file, **kwargs)


    def get_session_analysis_output_zip_info(self, session_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.sessions_api.get_session_analysis_output_zip_info(session_id, analysis_id, filename, **kwargs)


    def get_session_analysis_output_download_url(self, session_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.sessions_api.get_session_analysis_output_download_ticket(session_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_all_sessions(self, **kwargs):  # noqa: E501
        """Get a list of sessions

        Finds all sessions.

        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param bool join_avatars: add name and avatar to notes
        :param JoinType join: join file origins
        :param str user_id:
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[SessionListOutput]]
        """
        return self.sessions_api.get_all_sessions(**kwargs)


    def get_session(self, session_id, **kwargs):  # noqa: E501
        """Get a single session

        Get a single session

        :param str session_id: (required)
        :param bool join_avatars: add name and avatar to notes
        :param JoinType join:
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: SessionOutput
        """
        return self.sessions_api.get_session(session_id, **kwargs)


    def get_session_acquisitions(self, session_id, **kwargs):  # noqa: E501
        """List acquisitions in a session

        Get acquisitions.

        :param str session_id: (required)
        :param str collection_id:
        :param bool exhaustive:
        :param JoinType join:
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[AcquisitionListOutput],Page]
        """
        return self.sessions_api.get_session_acquisitions(session_id, **kwargs)


    def get_session_analyses(self, cid, **kwargs):  # noqa: E501
        """Get analyses for session.

        Returns analyses that directly belong to this resource.

        :param str cid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool inflate_job:
        :param bool join_avatars:
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[union[AnalysisListOutput,AnalysisListOutputInflatedJob]]]
        """
        return self.sessions_api.get_session_analyses(cid, **kwargs)


    def get_session_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.

        Get an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool join_avatars:
        :param JoinType join:
        :param bool async_: Perform the request asynchronously
        :return: union[AnalysisOutputInflatedJob,AnalysisOutput]
        """
        return self.sessions_api.get_session_analysis(cid, analysis_id, **kwargs)


    def get_session_file_info(self, cid, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str cid: (required)
        :param str filename: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.sessions_api.get_session_file_info(cid, filename, **kwargs)


    def get_session_jobs(self, session_id, **kwargs):  # noqa: E501
        """Return any jobs that use inputs from this session

        Gets session jobs.

        :param str session_id: (required)
        :param list[str] states: filter results by job state
        :param list[str] tags: filter results by job tags
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[JobsList,Page]
        """
        return self.sessions_api.get_session_jobs(session_id, **kwargs)


    def get_session_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Get a note on session.

        Get a note on session

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.sessions_api.get_session_note(cid, note_id, **kwargs)


    def get_session_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.sessions_api.get_session_tag(cid, value, **kwargs)


    def modify_session(self, session_id, body, **kwargs):  # noqa: E501
        """Update a session

        Modify a session.

        :param str session_id: (required)
        :param SessionModify body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.modify_session(session_id, body, **kwargs)


    def modify_session_analysis(self, cid, analysis_id, body, **kwargs):  # noqa: E501
        """Modify an analysis.

        Modify an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param AnalysisModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.modify_session_analysis(cid, analysis_id, body, **kwargs)


    def modify_session_file(self, cid, filename, body, **kwargs):  # noqa: E501
        """Modify a file&#x27;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list)

        :param str cid: (required)
        :param str filename: (required)
        :param FileModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.modify_session_file(cid, filename, body, **kwargs)


    def modify_session_file_classification(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.modify_session_file_classification(cid, filename, body, **kwargs)


    def modify_session_file_info(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update info for a particular file.

        Modify and return the file 'info' field

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.modify_session_file_info(cid, filename, body, **kwargs)


    def modify_session_info(self, cid, body, **kwargs):  # noqa: E501
        """Update or replace info for a session.

        Update or replace info for a session.

        :param str cid: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.sessions_api.modify_session_info(cid, body, **kwargs)


    def modify_session_note(self, cid, note_id, body, **kwargs):  # noqa: E501
        """Update a note on session.

        Update a note on session

        :param str cid: (required)
        :param str note_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.sessions_api.modify_session_note(cid, note_id, body, **kwargs)


    def rename_session_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.sessions_api.rename_session_tag(cid, value, body, **kwargs)


    def upload_file_to_session(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload a file to session.


        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param bool preserve_metadata:
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str metadata: Metadata object as a JSON-encoded string
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[FileOutput],UploadTicketOutput]
        """
        if signed:
            signed_result = self.signed_upload_file_to_session(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.sessions_api.upload_file_to_session(container_id, file, **kwargs)


    def upload_output_to_session_analysis(self, cid, analysis_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload an output file to analysis.

        Upload an output file to analysis

        :param str cid: (required)
        :param str analysis_id: (required)
        :param str file: The file to upload (required)
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: list[FileOutput]
        """
        if signed:
            signed_result = self.signed_upload_output_to_session_analysis(cid, analysis_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.sessions_api.upload_output_to_session_analysis(cid, analysis_id, file, **kwargs)


    def add_provider(self, body, **kwargs):  # noqa: E501
        """Add a new provider


        :param IngressProvider body: (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressProviderId
        """
        return self.site_api.add_provider(body, **kwargs)


    def add_site_rule(self, body, **kwargs):  # noqa: E501
        """Create a new site rule.


        :param GearRuleInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearRule
        """
        return self.site_api.add_site_rule(body, **kwargs)


    def delete_provider(self, provider_id, **kwargs):  # noqa: E501
        """Delete the provider identified by ProviderId

        Returns an empty 204 response if successful. The provider will be deleted asynchronously; if it is a storage provider, any files on the provider that have been deleted but not yet cleaned up will be hard deleted. Use the `get_provider` operation to check the deletion status.

        :param str provider_id: The ID of the provider (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.site_api.delete_provider(provider_id, **kwargs)


    def get_bookmark_list(self, **kwargs):  # noqa: E501
        """Get Bookmark List


        :param bool async_: Perform the request asynchronously
        :return: list[Bookmark]
        """
        return self.site_api.get_bookmark_list(**kwargs)


    def get_provider(self, provider_id, **kwargs):  # noqa: E501
        """Return the provider identified by ProviderId

        Return the provider identified by ProviderId

        :param str provider_id: The ID of the provider (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressProvider
        """
        return self.site_api.get_provider(provider_id, **kwargs)


    def get_provider_config(self, provider_id, **kwargs):  # noqa: E501
        """Return the configuration for provider identified by ProviderId

        The returned configuration will be redacted, with any privileged values replaced with null.

        :param str provider_id: The ID of the provider (required)
        :param bool async_: Perform the request asynchronously
        :return: object
        """
        return self.site_api.get_provider_config(provider_id, **kwargs)


    def get_providers(self, **kwargs):  # noqa: E501
        """Return a list of all providers on the site

        Return a list of all providers on the site

        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param ProviderClass _class: Limit the response to the given provider class
        :param bool async_: Perform the request asynchronously
        :return: list[EgressProvider]
        """
        return self.site_api.get_providers(**kwargs)


    def get_site_rule(self, rule_id, **kwargs):  # noqa: E501
        """Get a site rule.


        :param str rule_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearRule
        """
        return self.site_api.get_site_rule(rule_id, **kwargs)


    def get_site_rules(self, **kwargs):  # noqa: E501
        """List all site rules.


        :param int limit:
        :param str after_id:
        :param str name:
        :param bool async_: Perform the request asynchronously
        :return: list[GearRule]
        """
        return self.site_api.get_site_rules(**kwargs)


    def get_site_settings(self, **kwargs):  # noqa: E501
        """Return administrative site settings

        Returns the site settings, which includes center-pays gear list. If the site settings have never been created, then center_gears will be null, rather than an empty list.

        :param bool async_: Perform the request asynchronously
        :return: SiteSettings
        """
        return self.site_api.get_site_settings(**kwargs)


    def modify_bookmark_list(self, body, **kwargs):  # noqa: E501
        """Modify Bookmark List


        :param list[Bookmark] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: list[Bookmark]
        """
        return self.site_api.modify_bookmark_list(body, **kwargs)


    def modify_provider(self, provider_id, body, **kwargs):  # noqa: E501
        """Update the provider identified by ProviderId

        Update the provider identified by ProviderId

        :param str provider_id: The ID of the provider (required)
        :param IngressUpdateProvider body: (required)
        :param bool async_: Perform the request asynchronously
        :return: EgressProvider
        """
        return self.site_api.modify_provider(provider_id, body, **kwargs)


    def modify_site_rule(self, rule_id, body, **kwargs):  # noqa: E501
        """Update a site rule.


        :param str rule_id: (required)
        :param GearRuleModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: GearRule
        """
        return self.site_api.modify_site_rule(rule_id, body, **kwargs)


    def modify_site_settings(self, body, **kwargs):  # noqa: E501
        """Update administrative site settings


        :param IngressSiteSettings body: (required)
        :param bool async_: Perform the request asynchronously
        :return: SiteSettings
        """
        return self.site_api.modify_site_settings(body, **kwargs)


    def remove_site_rule(self, rule_id, **kwargs):  # noqa: E501
        """Remove a site rule.


        :param str rule_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.site_api.remove_site_rule(rule_id, **kwargs)


    def add_subject(self, body, **kwargs):  # noqa: E501
        """Create a new subject

        Create a new subject

        :param SubjectInput body: subject object to create (required)
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.subjects_api.add_subject(body, **kwargs)


    def add_subject_analysis(self, cid, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis.

        :param str cid: (required)
        :param union[AdhocAnalysisInput,JobAnalysisInput] body: (required)
        :param bool job: returns job_id instead of analysis.id
        :param bool job: returns job_id instead of analysis.id
        :param bool async_: Perform the request asynchronously
        :return: InsertedId
        """
        return self.subjects_api.add_subject_analysis(cid, body, **kwargs)


    def add_subject_analysis_note(self, container_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to subject analysis.


        :param str container_id: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param NoteInput body: note content (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.subjects_api.add_subject_analysis_note(container_id, analysis_id, body, **kwargs)


    def add_subject_note(self, container_id, body, **kwargs):  # noqa: E501
        """Add a note to subject.


        :param str container_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.subjects_api.add_subject_note(container_id, body, **kwargs)


    def add_subject_tag(self, cid, body, **kwargs):  # noqa: E501
        """Add a tag to subject.

        Propagates changes to projects, sessions and acquisitions

        :param str cid: (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.add_subject_tag(cid, body, **kwargs)


    def add_subject_tags(self, cid, body, **kwargs):  # noqa: E501
        """Add multiple tags to subject

        Add multiple tags to subject

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.subjects_api.add_subject_tags(cid, body, **kwargs)


    def create_master_subject_code(self, body, **kwargs):  # noqa: E501
        """Request a master subject code for the given patient

        The workflow is the following.   - send `patient_id` (e.g., MRN) and/or `first_name`, `last_name`, `date_of_birth`   - indicate whether to use `patient_id` for identification or `first_name`, `last_name`, `date_of_birth`     by the `use_patient_id` field   - the response will contain a master subject code   - if you send the same identifying information again, you will receive the same code  Note that if you received a MSC code for example by just providing the `patient_id`, you can save more information for that MSC in a second request (`first_name`, `last_name`, `date_of_birth`). Only the missing fields will be set, so you can't update any existing field (e.g. changing the name). Since you can create multiple MSC codes with the same name and date of birth using different patient ids, you will get HTTP 400 error if you request an MSC code by name and date of birth and there are multiple matches. In this case you need to use patient id.

        :param union[MasterSubjectCodeInput,MasterSubjectCodeDobInput] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: MasterSubjectCodeOutput
        """
        return self.subjects_api.create_master_subject_code(body, **kwargs)


    def delete_subject(self, subject_id, **kwargs):  # noqa: E501
        """Delete a subject

        Read-write project permissions are required to delete a subject. Admin project permissions are required if the subject or it's acquisitions contain data uploaded by sources other than users and jobs.

        :param str subject_id: 24-char hex subject id (required)
        :param ContainerDeleteReason delete_reason:
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.subjects_api.delete_subject(subject_id, **kwargs)


    def delete_subject_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis

        Delete an analysis for a container.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param ContainerDeleteReason delete_reason: Provide a reason for the deletion
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.subjects_api.delete_subject_analysis(cid, analysis_id, **kwargs)


    def delete_subject_analysis_note(self, cid, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from subject analysis.

        Remove a note from subject analysis.

        :param str cid: 24-char hex id (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str note_id: 24-char hex note id (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.subjects_api.delete_subject_analysis_note(cid, analysis_id, note_id, **kwargs)


    def delete_subject_file(self, cid, filename, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file.

        :param str cid: (required)
        :param str filename: (required)
        :param ContainerDeleteReason delete_reason: A reason for deletion when audit-trail is enabled
        :param bool force: Force deletion of the file even if some checks fail. Deprecated, will be removed in a future release.
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.subjects_api.delete_subject_file(cid, filename, **kwargs)


    def delete_subject_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Remove a note from subject

        Remove a note from subject

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.subjects_api.delete_subject_note(cid, note_id, **kwargs)


    def delete_subject_tag(self, cid, value, **kwargs):  # noqa: E501
        """Delete a tag

        Delete a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.subjects_api.delete_subject_tag(cid, value, **kwargs)


    def delete_subject_tags(self, cid, body, **kwargs):  # noqa: E501
        """Delete multiple tags from subject

        Delete multiple tags from subject

        :param str cid: (required)
        :param list[str] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.subjects_api.delete_subject_tags(cid, body, **kwargs)


    def download_file_from_subject(self, subject_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str subject_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.subjects_api.download_file_from_subject(subject_id, file_name, dest_file, **kwargs)


    def get_subject_file_zip_info(self, subject_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str subject_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.subjects_api.get_subject_file_zip_info(subject_id, file_name, **kwargs)


    def get_subject_download_url(self, subject_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str subject_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.subjects_api.get_subject_download_ticket(subject_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_subject_analysis(self, subject_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.subjects_api.download_input_from_subject_analysis(subject_id, analysis_id, filename, dest_file, **kwargs)


    def get_subject_analysis_input_zip_info(self, subject_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.subjects_api.get_subject_analysis_input_zip_info(subject_id, analysis_id, filename, **kwargs)


    def get_subject_analysis_input_download_url(self, subject_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: 24-char hex ticket id
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.subjects_api.get_subject_analysis_input_download_ticket(subject_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_subject_analysis(self, subject_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param str dest_file: Destination file path
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        return self.subjects_api.download_output_from_subject_analysis(subject_id, analysis_id, filename, dest_file, **kwargs)


    def get_subject_analysis_output_zip_info(self, subject_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: FileZipInfo
        """
        return self.subjects_api.get_subject_analysis_output_zip_info(subject_id, analysis_id, filename, **kwargs)


    def get_subject_analysis_output_download_url(self, subject_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param str ticket: ticket id of the outputs to download
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: union[DownloadTicketStub,ZipfileInfo]
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.subjects_api.get_subject_analysis_output_download_ticket(subject_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_all_subjects(self, **kwargs):  # noqa: E501
        """Get a list of subjects

        Get a list of subjects

        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param JoinType join: join file origins
        :param bool join_avatars: add name and avatar to notes
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[SubjectOutputForList]]
        """
        return self.subjects_api.get_all_subjects(**kwargs)


    def get_subject(self, subject_id, **kwargs):  # noqa: E501
        """Get a single subject

        Get an subject by its id  Args:     subject_id: The id of the subject     join: Attribute to join on     join_avatars: Join the user avatars for permissions     auth_session: The auth session  Returns:     SubjectOutput

        :param str subject_id: 24-char hex subject id (required)
        :param JoinType join: join file origins
        :param bool join_avatars: add name and avatar to notes
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: SubjectOutput
        """
        return self.subjects_api.get_subject(subject_id, **kwargs)


    def get_subject_analyses(self, cid, **kwargs):  # noqa: E501
        """Get analyses for subject.

        Returns analyses that directly belong to this resource.

        :param str cid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool inflate_job:
        :param bool join_avatars:
        :param JoinType join:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[union[AnalysisListOutput,AnalysisListOutputInflatedJob]]]
        """
        return self.subjects_api.get_subject_analyses(cid, **kwargs)


    def get_subject_analysis(self, cid, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.

        Get an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool join_avatars:
        :param JoinType join:
        :param bool async_: Perform the request asynchronously
        :return: union[AnalysisOutputInflatedJob,AnalysisOutput]
        """
        return self.subjects_api.get_subject_analysis(cid, analysis_id, **kwargs)


    def get_subject_file_info(self, cid, filename, **kwargs):  # noqa: E501
        """Get info for a particular file.

        Get info for a particular file.

        :param str cid: (required)
        :param str filename: (required)
        :param bool async_: Perform the request asynchronously
        :return: FileOutput
        """
        return self.subjects_api.get_subject_file_info(cid, filename, **kwargs)


    def get_subject_note(self, cid, note_id, **kwargs):  # noqa: E501
        """Get a note on subject.

        Get a note on subject

        :param str cid: (required)
        :param str note_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: Note
        """
        return self.subjects_api.get_subject_note(cid, note_id, **kwargs)


    def get_subject_sessions(self, subject_id, **kwargs):  # noqa: E501
        """List sessions of a subject

        List sessions of a subject

        :param str subject_id: 24-char hex subject id (required)
        :param JoinType join: join file origins
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[union[HeaderFeature,str]] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[SessionListOutput]]
        """
        return self.subjects_api.get_subject_sessions(subject_id, **kwargs)


    def get_subject_tag(self, cid, value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.

        Get the value of a tag, by name

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.subjects_api.get_subject_tag(cid, value, **kwargs)


    def modify_subject(self, subject_id, body, **kwargs):  # noqa: E501
        """Update a subject

        Update a subject

        :param str subject_id: 24-char hex subject id (required)
        :param SubjectModify body: subject object to modify (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.modify_subject(subject_id, body, **kwargs)


    def modify_subject_analysis(self, cid, analysis_id, body, **kwargs):  # noqa: E501
        """Modify an analysis.

        Modify an analysis.

        :param str cid: (required)
        :param str analysis_id: (required)
        :param AnalysisModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.modify_subject_analysis(cid, analysis_id, body, **kwargs)


    def modify_subject_file(self, cid, filename, body, **kwargs):  # noqa: E501
        """Modify a file&#x27;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list)

        :param str cid: (required)
        :param str filename: (required)
        :param FileModifyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.modify_subject_file(cid, filename, body, **kwargs)


    def modify_subject_file_classification(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.modify_subject_file_classification(cid, filename, body, **kwargs)


    def modify_subject_file_info(self, cid, filename, body, **kwargs):  # noqa: E501
        """Update info for a particular file.

        Modify and return the file 'info' field

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.modify_subject_file_info(cid, filename, body, **kwargs)


    def modify_subject_info(self, cid, body, **kwargs):  # noqa: E501
        """Update or replace info for a subject.

        Update or replace info for a subject.

        :param str cid: (required)
        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.subjects_api.modify_subject_info(cid, body, **kwargs)


    def modify_subject_note(self, cid, note_id, body, **kwargs):  # noqa: E501
        """Update a note on subject.

        Update a note on subject

        :param str cid: (required)
        :param str note_id: (required)
        :param NoteInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: int
        """
        return self.subjects_api.modify_subject_note(cid, note_id, body, **kwargs)


    def rename_subject_tag(self, cid, value, body, **kwargs):  # noqa: E501
        """Rename a tag.

        Rename a tag

        :param str cid: (required)
        :param str value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async_: Perform the request asynchronously
        :return: str
        """
        return self.subjects_api.rename_subject_tag(cid, value, body, **kwargs)


    def upload_file_to_subject(self, container_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload a file to subject.


        :param str container_id: (required)
        :param str file: The file to upload (required)
        :param bool preserve_metadata:
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str metadata: Metadata object as a JSON-encoded string
        :param list[str] x_accept_feature: redirect header
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[FileOutput],UploadTicketOutput]
        """
        if signed:
            signed_result = self.signed_upload_file_to_subject(container_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.subjects_api.upload_file_to_subject(container_id, file, **kwargs)


    def upload_output_to_subject_analysis(self, cid, analysis_id, file, signed=True, **kwargs):  # noqa: E501
        """Upload an output file to analysis.

        Upload an output file to analysis

        :param str cid: (required)
        :param str analysis_id: (required)
        :param str file: The file to upload (required)
        :param str ticket:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: list[FileOutput]
        """
        if signed:
            signed_result = self.signed_upload_output_to_subject_analysis(cid, analysis_id, file, **kwargs)
            if signed_result:
                return signed_result

        return self.subjects_api.upload_output_to_subject_analysis(cid, analysis_id, file, **kwargs)


    def verify_master_subject_code(self, code, **kwargs):  # noqa: E501
        """Verify that the given master subject code exists or not

        Verify that the given master subject code exists or not

        :param str code: code id (required)
        :param bool async_: Perform the request asynchronously
        :return: MasterSubjectCodeOutput
        """
        return self.subjects_api.verify_master_subject_code(code, **kwargs)


    def fetch_tree(self, body, **kwargs):  # noqa: E501
        """Query a portion of the flywheel hierarchy, returning only the requested fields.

        This is a build-your-own request endpoint that can fetch from anywhere in the hierarchy, returning just the fields that you care about.  # Fields Each fetch-level described must include a list of fields to return. These fields can be anything on the container (except info), and will be included in the response if they are present in the container.  # Joins Children or parents can be joined as part of this request, by specifying an additional subdocument of the given name. Check /tree/graph for a list of containers and their connections.  # Filter Joined documents can be further filtered (with the exception of inputs & files) by passing a filter in the subdocument. Filtering follows the same convention as top-level pagination.  # Sort Joined documents can be sorted as well, following the convention as top-level pagination.  # Limit Joins can be limited to a the first N documents by specifying a limit in the subdocument.  # Join-origin Passing `true` for the `join-origin` flag in the files subdocument will populates the `join-origin` map for each container with files.

        :param GraphFilter body: (required)
        :param bool exhaustive:
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[Page,list[object]]
        """
        return self.tree_api.fetch_tree(body, **kwargs)


    def get_tree_graph(self, **kwargs):  # noqa: E501
        """Get a description of the flywheel hiearchy

        Get a description of the flywheel hiearchy

        :param bool async_: Perform the request asynchronously
        :return: dict(str, TreeGraphNode)
        """
        return self.tree_api.get_tree_graph(**kwargs)


    def check_uids_exist(self, body, **kwargs):  # noqa: E501
        """Check for existence of UIDs system-wide

        Check if any of the given list of UIDs exist in the system

        :param union[UidCheckInputSessions,UidCheckInputAcquisitions] body: (required)
        :param bool async_: Perform the request asynchronously
        :return: UidCheckOutput
        """
        return self.uids_api.check_uids_exist(body, **kwargs)


    def cleanup_signed_upload_url(self, body, **kwargs):  # noqa: E501
        """Cleanup unused file blob previously uploaded using signed URL


        :param SignedUrlCleanupInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.upload_api.cleanup_signed_upload_url(body, **kwargs)


    def complete_s3_multipart_upload(self, body, **kwargs):  # noqa: E501
        """Complete S3 multipart signed url upload

        Complete S3 uploads exceeding 5GB and create the final object in the bucket. Expected an upload id returned previously by the `POST /upload/signed-url` endpoint and the e-tags returned by S3 after uploaded each file part.

        :param CompleteS3MultipartUploadInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: CompleteMultipartUploadOutput
        """
        return self.upload_api.complete_s3_multipart_upload(body, **kwargs)


    def create_signed_upload_url(self, body, **kwargs):  # noqa: E501
        """Create new signed upload URL

        Return a signed upload URL for the requested storage provider_id. Multiple URLs are returned for S3 uploads exceeding 5GB.

        :param SignedUrlUploadInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: SignedUrlUploadOutput
        """
        return self.upload_api.create_signed_upload_url(body, **kwargs)


    def upload_by_label(self, **kwargs):  # noqa: E501
        """Multipart form upload with N file fields, each with their desired filename.

        ### Default behavior: > For technical reasons, no form field names can be repeated. Instead, use   (file1, file2) and so forth.  > A non-file form field called \"metadata\" is also required, which must be   a string containing JSON.  > See ``api/schemas/input/labelupload.json`` for the format of this metadata.  ### Signed URL upload with ``ticket`` > Upload a single file directly to the storage backend. The workflow is the following:    - Send a request with an empty ``?ticket=`` query parameter to get an upload ticket and URL   - Upload the file using a PUT request to the upload URL   - Once done, send a POST request to this endpoint with the upload ticket to finalize the upload.   The file will be placed into the DB via this POST request.

        :param bool preserve_metadata:
        :param str ticket: Use empty value to get a ticket, and provide the ticket id to finalize the upload
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str files:
        :param object metadata: Metadata object
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[File],UploadTicketOutput]
        """
        return self.upload_api.upload_by_label(**kwargs)


    def upload_by_reaper(self, **kwargs):  # noqa: E501
        """Bottom-up UID matching of Multipart form upload with N file fields, each with their desired filename.

        ### Default behavior:  > Upload data, allowing users to move sessions during scans without causing new data to be   created in referenced project/group.  ### Evaluation Order:  * If a matching acquisition UID is found anywhere on the system, the related files will be placed under that acquisition. * **OR** If a matching session UID is found, a new acquistion is created with the specified UID under that Session UID. * **OR** If a matching group ID and project label are found, a new session and acquisition will be created within that project * **OR** If a matching group ID is found, a new project and session and acquisition will be created within that group. * **OR** A new session and acquisition will be created within a special \"Unknown\" group and project, which is only visible to system administrators.  ### Signed URL upload with ``ticket`` > Upload a single file directly to the storage backend. The workflow is the following:    - Send a request with an empty ``?ticket=`` query parameter to get an upload ticket and URL   - Upload the file using a PUT request to the upload URL   - Once done, send a POST request to this endpoint with the upload ticket to finalize the upload.   The file will be placed into the DB via this POST request.

        :param bool preserve_metadata:
        :param str ticket: Use empty value to get a ticket, and provide the ticket id to finalize the upload
        :param bool uid_placement:
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str files:
        :param object metadata: Metadata object
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[File],UploadTicketOutput]
        """
        return self.upload_api.upload_by_reaper(**kwargs)


    def upload_by_uid(self, **kwargs):  # noqa: E501
        """Multipart form upload with N file fields, each with their desired filename.

        ### Default behavior: > Same behavior as /api/upload/label,   except the metadata field must be uid format   See ``api/schemas/input/uidupload.json`` for the format of this metadata.  ### Signed URL upload with ``ticket`` > Upload a single file directly to the storage backend. The workflow is the following:    - Send a request with an empty ``?ticket=`` query parameter to get an upload ticket and URL   - Upload the file using a PUT request to the upload URL   - Once done, send a POST request to this endpoint with the upload ticket to finalize the upload.   The file will be placed into the DB via this POST request.

        :param bool preserve_metadata:
        :param str ticket: Use empty value to get a ticket, and provide the ticket id to finalize the upload
        :param str id:
        :param ContainerType level:
        :param str job:
        :param str files:
        :param object metadata: Metadata object
        :param str content_type:
        :param bool async_: Perform the request asynchronously
        :return: union[list[File],UploadTicketOutput]
        """
        return self.upload_api.upload_by_uid(**kwargs)


    def upload_signed_fs_file(self, token, body, **kwargs):  # noqa: E501
        """Upload file to local filesystem storage provider

        The POST `/api/upload/signed-url` endpoint returns a url with a jwt token pointing to this endpoint if the storage provider is a local filesystem then the file can be uploaded simply by sending the file content in the body of the payload. The destination storage provider and the file path are encoded in the jwt token.

        :param str token: Upload token (required)
        :param str body: Signed filesystem file upload payload (required)
        :param bool async_: Perform the request asynchronously
        :return: SignedFSUploadOutput
        """
        return self.upload_api.upload_signed_fs_file(token, body, **kwargs)


    def add_user(self, body, **kwargs):  # noqa: E501
        """Add a new user


        :param UserInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: UserOutputId
        """
        return self.users_api.add_user(body, **kwargs)


    def delete_user(self, user_id, **kwargs):  # noqa: E501
        """Delete a user


        :param str user_id: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.users_api.delete_user(user_id, **kwargs)


    def delete_user_key(self, id_, **kwargs):  # noqa: E501
        """Delete User Api Key


        :param str id_: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.users_api.delete_user_key(id_, **kwargs)


    def generate_user_key(self, body, **kwargs):  # noqa: E501
        """Generates user api key

        Generate user api key for the current user.

        :param CoreModelsApiKeyApiKeyInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ApiKeyOutput
        """
        return self.users_api.generate_user_key(body, **kwargs)


    def get_all_users(self, **kwargs):  # noqa: E501
        """Return a list of all users

        Gets all users with pagination  Args:

        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return
        :param int skip: The number of entries to skip
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[UserOutput],OutputUserPage]
        """
        return self.users_api.get_all_users(**kwargs)


    def get_current_user(self, **kwargs):  # noqa: E501
        """Get information about the current user

        Gets the current user  Args:     auth_session (AuthSession): session from incoming request Returns:     CurrentUserOutput: Pydantic model for client side user data

        :param bool async_: Perform the request asynchronously
        :return: CurrentUserOutput
        """
        return self.users_api.get_current_user(**kwargs)


    def get_current_user_avatar(self, **kwargs):  # noqa: E501
        """Get the avatar of the current user

        Gets avatar of current user  Args:     auth_session (AuthSession): session from incoming request Returns:     str: url of avatar

        :param str default:
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.users_api.get_current_user_avatar(**kwargs)


    def get_current_user_info(self, **kwargs):  # noqa: E501
        """Get info of the current user

        Gets user info fields.  Args:     fields (str): csv of arbitrary keys to look for in user info     auth_session (AuthSession): session from incoming request Returns:     dict: arbitrary data matching the provided csv values

        :param str fields: Get only the specified fields from user's info. Accept multiple fields separated by comma. 
        :param bool async_: Perform the request asynchronously
        :return: object
        """
        return self.users_api.get_current_user_info(**kwargs)


    def get_current_user_jobs(self, **kwargs):  # noqa: E501
        """Return list of jobs created by the current user

        Gets jobs assigned to user with optional gear name regex  Args:     gear_name (str): name of gear to filter by     auth_session (AuthSession): session from incoming request Returns:     list: List of jobs linked to the user

        :param str gear: Gear name. Get only the jobs which are related to a specific gear. 
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool exhaustive:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: UserJobs
        """
        return self.users_api.get_current_user_jobs(**kwargs)


    def get_user(self, user_id, **kwargs):  # noqa: E501
        """Get information about the specified user

        Get user by id  Args:     uid (str): string matching uid pattern Returns:     UserOutput: Pydantic model for sending data to client

        :param str user_id: (required)
        :param bool include_deleted:
        :param bool async_: Perform the request asynchronously
        :return: UserOutput
        """
        return self.users_api.get_user(user_id, **kwargs)


    def get_user_acquisitions(self, uid, **kwargs):  # noqa: E501
        """Get all acquisitions that belong to the given user.


        :param str uid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool async_: Perform the request asynchronously
        :return: list[AcquisitionListOutput]
        """
        return self.users_api.get_user_acquisitions(uid, **kwargs)


    def get_user_avatar(self, user_id, **kwargs):  # noqa: E501
        """Get the avatar of the specified user

        gets avatar of user and redirects to it  Args:     user_id (str): user id matching user_id regex Returns:     RedirectResponse: redirects user to avatar Raises (ResourceNotFound): Raises 404 if no user avatar

        :param str user_id: (required)
        :param str default:
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.users_api.get_user_avatar(user_id, **kwargs)


    def get_user_collections(self, user_id, **kwargs):  # noqa: E501
        """Get all collections that belong to the given user.


        :param str user_id: (required)
        :param str filter:
        :param str sort:
        :param int limit:
        :param int skip:
        :param int page:
        :param str after_id:
        :param list[str] x_accept_feature:
        :param bool async_: Perform the request asynchronously
        :return: union[list[CollectionWithStats],list[CollectionOutput],Page]
        """
        return self.users_api.get_user_collections(user_id, **kwargs)


    def get_user_groups(self, uid, **kwargs):  # noqa: E501
        """List all groups the specified user is a member of


        :param str uid: (required)
        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param list[str] x_accept_feature: redirect header
        :param bool async_: Perform the request asynchronously
        :return: list[GroupOutput]
        """
        return self.users_api.get_user_groups(uid, **kwargs)


    def get_user_projects(self, uid, **kwargs):  # noqa: E501
        """Get all projects that belong to the given user.


        :param str uid: (required)
        :param str filter: The filter to apply. (e.g. label=my-label,created>2018-09-22)
        :param str sort: The sort fields and order. (e.g. label:asc,created:desc)
        :param int limit: The maximum number of entries to return.
        :param int skip: The number of entries to skip.
        :param int page: The page number (i.e. skip limit*page entries)
        :param str after_id: Paginate after the given id. (Cannot be used with sort, page or skip)
        :param bool exhaustive: Set to return a complete list regardless of permissions
        :param bool async_: Perform the request asynchronously
        :return: list[ProjectListOutput]
        """
        return self.users_api.get_user_projects(uid, **kwargs)


    def get_user_sessions(self, uid, **kwargs):  # noqa: E501
        """Get all sessions that belong to the given user.

        Get all sessions that belong to the given user.

        :param str uid: (required)
        :param str filter:
        :param str sort:
        :param int limit:
        :param int skip:
        :param int page:
        :param str after_id:
        :param bool exhaustive:
        :param bool async_: Perform the request asynchronously
        :return: list[SessionListOutput]
        """
        return self.users_api.get_user_sessions(uid, **kwargs)


    def modify_current_user_info(self, body, **kwargs):  # noqa: E501
        """Update or replace info for the current user.

        Modifies user info fields  Args:     info (Info): Model representing arbitrary data     auth_session (AuthSession): session from incoming request Returns:     None

        :param Info body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.users_api.modify_current_user_info(body, **kwargs)


    def modify_user(self, uid, body, **kwargs):  # noqa: E501
        """Update the specified user


        :param str uid: (required)
        :param ModifyUserInput body: (required)
        :param bool clear_permissions:
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.users_api.modify_user(uid, body, **kwargs)


    def sync_user(self, cid, body, **kwargs):  # noqa: E501
        """Sync a center user to enterprise (Sync service use ONLY)


        :param str cid: (required)
        :param SyncUserInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.users_api.sync_user(cid, body, **kwargs)


    def data_view_columns(self, **kwargs):  # noqa: E501
        """Return a list of all known column aliases for use in data views


        :param bool async_: Perform the request asynchronously
        :return: list[DataViewColumnAlias]
        """
        return self.views_api.data_view_columns(**kwargs)


    def delete_view(self, view_id, **kwargs):  # noqa: E501
        """Delete a data view

        Soft deletes data view in database

        :param str view_id: The ID of the view (required)
        :param bool async_: Perform the request asynchronously
        :return: DeletedResult
        """
        return self.views_api.delete_view(view_id, **kwargs)


    def evaluate_view(self, view_id, container_id, **kwargs):  # noqa: E501
        """Execute a view, returning data in the preferred format.


        :param str view_id: The ID of the view (required)
        :param str container_id: The target container for view execution (required)
        :param str ticket: download ticket id
        :param str filename: download ticket filename
        :param FileFormat format: Available values : csv, tsv, json, ndjson, json_flat, json-row-column
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param str filter: An optional filter expression
        :param int skip: The optional number of rows to skip
        :param int limit: The optional max number of rows to return
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.views_api.evaluate_view(view_id, container_id, **kwargs)


    def evaluate_view_adhoc(self, container_id, body, **kwargs):  # noqa: E501
        """Execute an ad-hoc view, returning data in the preferred format.


        :param str container_id: The target container for view execution (required)
        :param ContainerPipelineInput body: (required)
        :param str filename: download ticket filename
        :param FileFormat format: Available values : csv, tsv, json, ndjson, json_flat, json-row-column
        :param str ticket: download ticket id
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param str filter: An optional filter expression
        :param int skip: The optional number of rows to skip
        :param int limit: The optional max number of rows to return
        :param bool async_: Perform the request asynchronously
        :return: None
        """
        return self.views_api.evaluate_view_adhoc(container_id, body, **kwargs)


    def get_view(self, view_id, **kwargs):  # noqa: E501
        """Return the view identified by ViewId


        :param str view_id: The ID of the view (required)
        :param bool async_: Perform the request asynchronously
        :return: ViewOutput
        """
        return self.views_api.get_view(view_id, **kwargs)


    def modify_view(self, view_id, body, **kwargs):  # noqa: E501
        """Update the view identified by ViewId


        :param str view_id: The ID of the view (required)
        :param ContainerPipelineInput body: (required)
        :param bool async_: Perform the request asynchronously
        :return: ModifiedResult
        """
        return self.views_api.modify_view(view_id, body, **kwargs)


    def queue_adhoc(self, container_id, body, **kwargs):  # noqa: E501
        """Execute an ad-hoc view, returning a reference to the created data view execution.


        :param str container_id: The target container for view execution (required)
        :param ContainerPipelineInput body: (required)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param str filter: An optional filter expression
        :param int skip: The optional number of rows to skip
        :param int limit: The optional max number of rows to return
        :param bool async_: Perform the request asynchronously
        :return: DataViewExecution
        """
        return self.views_api.queue_adhoc(container_id, body, **kwargs)


    def queue_saved(self, view_id, container_id, **kwargs):  # noqa: E501
        """Execute a view, returning a reference to the created data view execution.

        Execute a view, returning a reference to the created data view execution.

        :param str view_id: The ID of the view (required)
        :param str container_id: The target container for view execution (required)
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param str filter: An optional filter expression
        :param int skip: The optional number of rows to skip
        :param int limit: The optional max number of rows to return
        :param bool async_: Perform the request asynchronously
        :return: DataViewExecution
        """
        return self.views_api.queue_saved(view_id, container_id, **kwargs)


    def save_view_data_to_container(self, container_id, body, **kwargs):  # noqa: E501
        """Execute a view, saving data to the target container / file

        Execute a view, saving data to the target container / file

        :param str container_id: The target container for view execution (required)
        :param ContainerIdViewInputExecuteAndSave body: (required)
        :param FileFormat format: Available values : csv, tsv, json, ndjson, json_flat, json-row-column
        :param str ticket: download ticket id
        :param str filter: An optional filter expression
        :param str sort: The sort fields and order.(e.g. label:asc,created:desc)
        :param int skip: The optional number of rows to skip
        :param int limit: The optional max number of rows to return
        :param bool async_: Perform the request asynchronously
        :return: File
        """
        return self.views_api.save_view_data_to_container(container_id, body, **kwargs)


    def enable_feature(self, value):
        """Enable feature named value, via the x-accept-feature header"""
        features = self.api_client.default_headers.get('x-accept-feature')
        features = features + ',' + value if features else value
        self.api_client.set_default_header('x-accept-feature', features)

    def perform_version_check(self):
        import re
        import warnings

        VERSION_RE = re.compile(r'^(?P<semver>(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<patch>\d+)))+.*')
        release_version = '' # Older core only version
        flywheel_version = None # Newer umbrella version for entire application
        try:
            version_info = self.default_api.get_version()
            release_version = version_info.release
            flywheel_version = getattr(version_info, 'flywheel_release', None)
        except:
            pass

        # If not sdk version
        # Prefer the newer flywheel version but fallback to the older release version
        sdk_version_match = VERSION_RE.match(SDK_VERSION)
        if flywheel_version:
            release_version_match = VERSION_RE.match(flywheel_version)
        elif release_version:
            release_version_match = VERSION_RE.match(release_version)
        else:
            release_version_match = None

        # Log conditionals:
        # 1. Client or server version not set
        # 2. Major version mismatch
        # 3. SDK Minor version > Server Minor version (client features not available on server)
        # 4. SDK Minor version < Server Minor version (new features on server)

        show_pip_message = False
        if sdk_version_match and release_version_match:
            # Compare major/minor version
            sdk_major = int(sdk_version_match.group('major'))
            sdk_minor = int(sdk_version_match.group('minor'))

            release_major = int(release_version_match.group('major'))
            release_minor = int(release_version_match.group('minor'))

            if sdk_major != release_major:
                if SDK_VERSION.find('dev') == -1:
                    # Always print version mismatch
                    warnings.warn('Client version {} does not match server version {}. Please update your client version!'.format(SDK_VERSION, release_version))
                    show_pip_message = True

            elif self.check_version:
                if sdk_minor > release_minor:
                    log.warning('Client version {} is ahead of server version {}. '.format(SDK_VERSION, release_version) +
                        'Not all client functionality will be supported by the server.')
                    show_pip_message = True
                elif sdk_minor < release_minor:
                    log.warning('Client version {} is behind server version {}. '.format(SDK_VERSION, release_version) +
                        'Please consider upgrading your client to access all available functionality.')
                    show_pip_message = True
        elif self.check_version:
            warnings.warn('Client or server version not available! This is an unsupported configuration!')

        if show_pip_message:
            log.warning('Use "pip install flywheel-sdk~={}" '.format(release_version_match.group('semver')) +
                'to install a compatible version for this server')

    def add_nodes_to_collection(self, collection_id, level, node_ids, **kwargs):
        """Generic method to add a list of nodes to a collection.

        :param str collection_id: (required) The id of the collection to update
        :param str level: (required) The level of nodes to add (e.g. session or acquisition)
        :param list[str] node_ids: (required) The list of node ids of type level to add
        :return: None
        """
        update = {
            'contents': {
                'operation': 'add',
                'nodes': [ {'_id': id, 'level': level} for id in node_ids ]
            }
        }
        return self.collections_api.modify_collection(collection_id, update, **kwargs)

    def add_sessions_to_collection(self, collection_id, session_ids, **kwargs):
        """Add a list of sessions to a collection.

        :param str collection_id: (required) The id of the collection to update
        :param list[str] session_ids: (required) The list of session ids to add
        :return: None
        """
        return self.add_nodes_to_collection(collection_id, 'session', session_ids, **kwargs)

    def add_acquisitions_to_collection(self, collection_id, acquisition_ids, **kwargs):
        """Add a list of acquisitions to a collection.

        :param str collection_id: (required) The id of the collection to update
        :param list[str] acquisition_ids: (required) The list of acquisition ids to add
        :return: None
        """
        return self.add_nodes_to_collection(collection_id, 'acquisition', acquisition_ids, **kwargs)

    def change_job_state(self, job_id, state):
        """Change a job state.

        :param str job_id: (required) The id of the job to modify
        :param str state: (required) The new job state
        :return: None
        """
        return self.modify_job(job_id, { 'state': state })

    def get(self, id, **kwargs):
        """Retrieve the specified object by id.

        Objects that can be retrieved in this way are:
            group, project, session, subject, acquisition, analysis and collection

        :param str id: The id of the object to retrieve
        :return: ContainerOutput
        """
        return self.get_container(id, **kwargs)

    def resolve(self, path, **kwargs):
        """Perform a path based lookup of nodes in the Flywheel hierarchy.

        :param str path: (required) The path to resolve
        :return: ResolverOutput
        """
        if not isinstance(path, list):
            path = path.split('/')

        return self.resolve_path(flywheel.ResolverInput(path=path), **kwargs)

    def lookup(self, path):
        """Perform a path based lookup of a single node in the Flywheel hierarchy.

        :param str path: (required) The path to resolve
        :return: ResolverOutput
        """
        if not isinstance(path, list):
            path = path.split('/')

        return self.lookup_path(flywheel.ResolverInput(path=path))

    def file_url(self, path):
        """Perform a path based lookup of a file in the Flywheel hierarchy, and return a single-use download URL.

        :param str path: (required) The path to resolve
        :return: The file URL if found, otherwise raises an error
        """
        result = self.resolve(path)
        if getattr(result.path[-1], 'container_type', None) != 'file':
            raise ValueError('Resolved path is not a file!')

        return result.path[-1].url()

    def download_tar(self, containers, dest_file, include_types=None, exclude_types=None):
        """Download the given set of containers as a tarball to dest_file.

        Supports downloading Projects, Sessions, Acquisitions and/or Analyses.

        :param containers: (required) The container, or list of containers to download.
        :param str dest_file: (required) The destination file on disk
        :param list include_types: The optional list of types to include in the download (e.g. ['nifti'])
        :param list exclude_types: The optional list of types to exclude from the download (e.g. ['dicom'])
        :return: A summary of the download
        """
        return self._download(
            containers,
            dest_file,
            "tar",
            include_types=include_types,
            exclude_types=exclude_types,
        )

    def download_zip(self, containers, dest_file, include_types=None, exclude_types=None):
        """Download the given set of containers as a zip archive to dest_file.

        Supports downloading Projects, Sessions, Acquisitions and/or Analyses.

        :param containers: (required) The container, or list of containers to download.
        :param str dest_file: (required) The destination file on disk
        :param list include_types: The optional list of types to include in the download (e.g. ['nifti'])
        :param list exclude_types: The optional list of types to exclude from the download (e.g. ['dicom'])
        :return: A summary of the download
        """
        return self._download(
            containers,
            dest_file,
            "zip",
            include_types=include_types,
            exclude_types=exclude_types,
        )

    def _download(self, containers, dest_file, format, include_types=None, exclude_types=None):
        if not isinstance(containers, list):
            containers = [containers]

        # Extract the list of nodes
        nodes = []
        for container in containers:
            container_type = getattr(container, 'container_type', None)
            if container_type is None:
                raise ValueError('Unknown container specified!')

            nodes.append(flywheel.DownloadNode(level=container_type, id=container.id))

        # Setup filters
        type_filter = None
        if include_types or exclude_types:
            type_filter = flywheel.DownloadFilterDefinition(plus=include_types, minus=exclude_types)

        download_filters = None
        if type_filter:
            download_filters = [flywheel.DownloadFilter(types=type_filter)]

        # Create download request
        request = flywheel.Download(nodes=nodes, filters=download_filters, optional=True)
        summary = self.create_download_ticket(request)

        # Perform download
        self.download_ticket(summary.ticket, dest_file, format=format)
        return summary

    def download_file_from_acquisition_as_data(self, acquisition_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str acquisition_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.acquisitions_api.download_file_from_acquisition_with_http_info(acquisition_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_acquisition_analysis_as_data(self, acquisition_id, analysis_id, filename, **kwargs):
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.acquisitions_api.download_input_from_acquisition_analysis_with_http_info(acquisition_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_acquisition_analysis_as_data(self, acquisition_id, analysis_id, filename, **kwargs):
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str acquisition_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.acquisitions_api.download_output_from_acquisition_analysis_with_http_info(acquisition_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_acquisition_file_classification(self, cid, filename, body, **kwargs):
        """Update classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'add': body }
        return self.acquisitions_api.modify_acquisition_file_classification(cid, filename, body, **kwargs)

    def replace_acquisition_file_classification(self, cid, filename, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.acquisitions_api.modify_acquisition_file_classification(cid, filename, body, **kwargs)

    def delete_acquisition_file_classification_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.acquisitions_api.modify_acquisition_file_classification(cid, filename, body, **kwargs)

    def set_acquisition_file_info(self, cid, filename, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.acquisitions_api.modify_acquisition_file_info(cid, filename, body, **kwargs)

    def replace_acquisition_file_info(self, cid, filename, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.acquisitions_api.modify_acquisition_file_info(cid, filename, body, **kwargs)

    def delete_acquisition_file_info_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.acquisitions_api.modify_acquisition_file_info(cid, filename, body, **kwargs)

    def set_acquisition_info(self, cid, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.acquisitions_api.modify_acquisition_info(cid, body, **kwargs)

    def replace_acquisition_info(self, cid, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.acquisitions_api.modify_acquisition_info(cid, body, **kwargs)

    def delete_acquisition_info_fields(self, cid, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.acquisitions_api.modify_acquisition_info(cid, body, **kwargs)

    def download_input_from_analysis_as_data(self, analysis_id, filename, **kwargs):
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: input filename (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.analyses_api.download_input_from_analysis_with_http_info(analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_analysis_as_data(self, analysis_id, filename, **kwargs):
        """Get Output File

        Get Output File

        :param str analysis_id: 24-character hex ID (required)
        :param str filename: output file name (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.analyses_api.download_output_from_analysis_with_http_info(analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_analysis_info(self, container_id, body, **kwargs):
        """Update info with the provided fields.

        :param str container_id: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.analyses_api.modify_analysis_info(container_id, body, **kwargs)

    def replace_analysis_info(self, container_id, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str container_id: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.analyses_api.modify_analysis_info(container_id, body, **kwargs)

    def delete_analysis_info_fields(self, container_id, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str container_id: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.analyses_api.modify_analysis_info(container_id, body, **kwargs)

    def download_file_from_collection_as_data(self, collection_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str collection_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.collections_api.download_file_from_collection_with_http_info(collection_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def set_collection_file_classification(self, cid, filename, body, **kwargs):
        """Update classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'add': body }
        return self.collections_api.modify_collection_file_classification(cid, filename, body, **kwargs)

    def replace_collection_file_classification(self, cid, filename, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.collections_api.modify_collection_file_classification(cid, filename, body, **kwargs)

    def delete_collection_file_classification_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.collections_api.modify_collection_file_classification(cid, filename, body, **kwargs)

    def set_collection_file_info(self, cid, filename, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.collections_api.modify_collection_file_info(cid, filename, body, **kwargs)

    def replace_collection_file_info(self, cid, filename, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.collections_api.modify_collection_file_info(cid, filename, body, **kwargs)

    def delete_collection_file_info_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.collections_api.modify_collection_file_info(cid, filename, body, **kwargs)

    def set_collection_info(self, cid, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.collections_api.modify_collection_info(cid, body, **kwargs)

    def replace_collection_info(self, cid, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.collections_api.modify_collection_info(cid, body, **kwargs)

    def delete_collection_info_fields(self, cid, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.collections_api.modify_collection_info(cid, body, **kwargs)

    def download_file_from_container_as_data(self, container_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str container_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.containers_api.download_file_from_container_with_http_info(container_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_container_analysis_as_data(self, container_id, analysis_id, filename, **kwargs):
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.containers_api.download_input_from_container_analysis_with_http_info(container_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_container_analysis_as_data(self, container_id, analysis_id, filename, **kwargs):
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str container_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.containers_api.download_output_from_container_analysis_with_http_info(container_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_container_file_classification(self, cid, filename, body, **kwargs):
        """Update classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'add': body }
        return self.containers_api.modify_container_file_classification(cid, filename, body, **kwargs)

    def replace_container_file_classification(self, cid, filename, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.containers_api.modify_container_file_classification(cid, filename, body, **kwargs)

    def delete_container_file_classification_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.containers_api.modify_container_file_classification(cid, filename, body, **kwargs)

    def set_container_file_info(self, cid, filename, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.containers_api.modify_container_file_info(cid, filename, body, **kwargs)

    def replace_container_file_info(self, cid, filename, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.containers_api.modify_container_file_info(cid, filename, body, **kwargs)

    def delete_container_file_info_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.containers_api.modify_container_file_info(cid, filename, body, **kwargs)

    def set_container_info(self, cid, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.containers_api.modify_container_info(cid, body, **kwargs)

    def replace_container_info(self, cid, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.containers_api.modify_container_info(cid, body, **kwargs)

    def delete_container_info_fields(self, cid, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.containers_api.modify_container_info(cid, body, **kwargs)

    def download_ticket_as_data(self, ticket, **kwargs):
        """Download files listed in the given ticket.

        You can use POST to create a download ticket The files listed in the ticket are put into a tar archive

        :param str ticket: ID of the download ticket (required)
        :param DownloadFormat format:
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.download_api.download_ticket_with_http_info(ticket, **kwargs)
        if resp:
            return resp.content
        return None

    def download_file_from_project_as_data(self, project_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str project_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.projects_api.download_file_from_project_with_http_info(project_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_project_analysis_as_data(self, project_id, analysis_id, filename, **kwargs):
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.projects_api.download_input_from_project_analysis_with_http_info(project_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_project_analysis_as_data(self, project_id, analysis_id, filename, **kwargs):
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str project_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.projects_api.download_output_from_project_analysis_with_http_info(project_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_project_file_classification(self, cid, filename, body, **kwargs):
        """Update classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'add': body }
        return self.projects_api.modify_project_file_classification(cid, filename, body, **kwargs)

    def replace_project_file_classification(self, cid, filename, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.projects_api.modify_project_file_classification(cid, filename, body, **kwargs)

    def delete_project_file_classification_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.projects_api.modify_project_file_classification(cid, filename, body, **kwargs)

    def set_project_file_info(self, cid, filename, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.projects_api.modify_project_file_info(cid, filename, body, **kwargs)

    def replace_project_file_info(self, cid, filename, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.projects_api.modify_project_file_info(cid, filename, body, **kwargs)

    def delete_project_file_info_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.projects_api.modify_project_file_info(cid, filename, body, **kwargs)

    def set_project_info(self, cid, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.projects_api.modify_project_info(cid, body, **kwargs)

    def replace_project_info(self, cid, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.projects_api.modify_project_info(cid, body, **kwargs)

    def delete_project_info_fields(self, cid, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.projects_api.modify_project_info(cid, body, **kwargs)

    def download_file_from_session_as_data(self, session_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str session_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.sessions_api.download_file_from_session_with_http_info(session_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_session_analysis_as_data(self, session_id, analysis_id, filename, **kwargs):
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.sessions_api.download_input_from_session_analysis_with_http_info(session_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_session_analysis_as_data(self, session_id, analysis_id, filename, **kwargs):
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str session_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.sessions_api.download_output_from_session_analysis_with_http_info(session_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_session_file_classification(self, cid, filename, body, **kwargs):
        """Update classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'add': body }
        return self.sessions_api.modify_session_file_classification(cid, filename, body, **kwargs)

    def replace_session_file_classification(self, cid, filename, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.sessions_api.modify_session_file_classification(cid, filename, body, **kwargs)

    def delete_session_file_classification_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.sessions_api.modify_session_file_classification(cid, filename, body, **kwargs)

    def set_session_file_info(self, cid, filename, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.sessions_api.modify_session_file_info(cid, filename, body, **kwargs)

    def replace_session_file_info(self, cid, filename, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.sessions_api.modify_session_file_info(cid, filename, body, **kwargs)

    def delete_session_file_info_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.sessions_api.modify_session_file_info(cid, filename, body, **kwargs)

    def set_session_info(self, cid, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.sessions_api.modify_session_info(cid, body, **kwargs)

    def replace_session_info(self, cid, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.sessions_api.modify_session_info(cid, body, **kwargs)

    def delete_session_info_fields(self, cid, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.sessions_api.modify_session_info(cid, body, **kwargs)

    def download_file_from_subject_as_data(self, subject_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported.  When virus_scan feature is enabled the quarantined files only can be downloaded using signed urls otherwise it will return with a HTTP 400 response.

        :param str subject_id: 24-char hex id (required)
        :param str file_name: output file name (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param int version: version of the file to download
        :param str hash: file hash for comparison
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.subjects_api.download_file_from_subject_with_http_info(subject_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_subject_analysis_as_data(self, subject_id, analysis_id, filename, **kwargs):
        """Download analysis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the analysis. If no \"ticket\" query param is included, inputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: get file info only
        :param str member: get zipfile member
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.subjects_api.download_input_from_subject_analysis_with_http_info(subject_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_subject_analysis_as_data(self, subject_id, analysis_id, filename, **kwargs):
        """Download analysis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the analysis. If no \"ticket\" query param is included, outputs will be downloaded directly.

        :param str subject_id: 24-character hex ID (required)
        :param str analysis_id: 24-char hex analysis id (required)
        :param str filename: filename to download (get tar of all if empty) (required)
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool view: feature flag for view/download
        :param str range: byte ranges to return
        :param list[str] x_accept_feature: redirect header
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.subjects_api.download_output_from_subject_analysis_with_http_info(subject_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_subject_file_classification(self, cid, filename, body, **kwargs):
        """Update classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'add': body }
        return self.subjects_api.modify_subject_file_classification(cid, filename, body, **kwargs)

    def replace_subject_file_classification(self, cid, filename, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.subjects_api.modify_subject_file_classification(cid, filename, body, **kwargs)

    def delete_subject_file_classification_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param FileClassificationDelta body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.subjects_api.modify_subject_file_classification(cid, filename, body, **kwargs)

    def set_subject_file_info(self, cid, filename, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.subjects_api.modify_subject_file_info(cid, filename, body, **kwargs)

    def replace_subject_file_info(self, cid, filename, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.subjects_api.modify_subject_file_info(cid, filename, body, **kwargs)

    def delete_subject_file_info_fields(self, cid, filename, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param str filename: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.subjects_api.modify_subject_file_info(cid, filename, body, **kwargs)

    def set_subject_info(self, cid, body, **kwargs):
        """Update info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'set': body }
        return self.subjects_api.modify_subject_info(cid, body, **kwargs)

    def replace_subject_info(self, cid, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'replace': body }
        return self.subjects_api.modify_subject_info(cid, body, **kwargs)

    def delete_subject_info_fields(self, cid, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str cid: (required)
        :param Info body: (required)
        :return: ModifiedResult
        """
        body = { 'delete': body }
        return self.subjects_api.modify_subject_info(cid, body, **kwargs)


    def View(self, **kwargs):
        """Short-hand for ``flywheel.ViewBuilder(**kwargs).build()``

        :param kwargs: The arguments to pass directly to ViewBuilder
        :return: The built data view
        """
        return ViewBuilder(**kwargs).build()

    def print_view_columns(self, filter=None, limit=25, file=sys.stdout):
        """Print a list of column aliases that can be used in data views.

        :param str filter: The filter for available columns
        :param int limit: The limit for the number of columns to return
        :param file-like file: The file to print to
        """
        columns = self.views_api.data_view_columns()
        columns = [
            column.to_dict()
            for column in columns
            if filter is None or filter.lower() in column.name.lower()
        ]
        if filter:
            self._fw.api_client.call_api(
                "/dataexplorer/search/fields",
                "POST",
                body={"field": filter},
                auth_settings=["ApiKey"],
            )
            elastic_columns = self._fw.api_client.last_response.data
            # Concat elastic fields
            columns = elastic_columns + columns
        for column in columns[:limit]:
            if column.get("group"):
                coltype = "group"
            else:
                coltype = column.get("type")
            six.print_('{} ({}): {}'.format(column["name"], coltype, column.get("description", "")), file=file)

    def read_view_data(self, view, container_id, decode=True, **kwargs):
        """Execute a data view against container, and return a file-like object that can be streamed.

        :param view: The view id or DataView object to execute.
        :type view: str or DataView
        :param str container_id: The id of the container to execute the view against
        :param bool decode: Whether or not to decode the stream to utf-8 (default is true)
        :param kwargs: Additional arguments to pass to the evaluate_view call. (e.g. format='csv')
        :return: A file-like object where the contents can be read
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False

        current_version = self.get_version().get("release")
        parsed_version = None
        try:
            parsed_version = version.parse(current_version)
        except version.InvalidVersion:
            pass
        if parsed_version is not None and parsed_version < version.parse("16.8.0"):
            if not isinstance(view, six.string_types):
                if view.error_column is not None:
                    log.warning(
                        "Error column not supported with %s API version, value will be ignored",
                        current_version
                    )
                view.swagger_types.pop("error_column", None)

        if self.get_config().get("features").get("task_manager_data_views"):
            view_format = kwargs.pop('format', 'json')

            if isinstance(view, six.string_types):
                resp = self.views_api.queue_saved(view, container_id, **kwargs)
            else:

                resp = self.views_api.queue_adhoc(container_id, view, **kwargs)

            data_view_execution_id = resp.json()["_id"]

            while True:
                data_view_execution = self.get_data_view_execution(data_view_execution_id)
                if data_view_execution.state == 'failed':
                    raise RuntimeError("Execution of data view failed")
                if data_view_execution.state == 'completed':
                    break
                time.sleep(1)

            kwargs['file_format'] = view_format
            retrieve_data_kwargs = {k: v for k, v in kwargs.items() if k not in ["filter", "skip", "limit"]}

            resp = self.get_data_view_execution_data(data_view_execution_id, **retrieve_data_kwargs)
        else:
            if isinstance(view, six.string_types):
                resp = self.views_api.evaluate_view_with_http_info(view, container_id, **kwargs)
            else:
                resp = self.views_api.evaluate_view_adhoc_with_http_info(container_id, view, **kwargs)
        resp.raw.decode_content = True
        if decode:
            return codecs.getreader(resp.encoding)(resp.raw)
        return resp.raw


    def read_view_dataframe(self, view, container_id, opts=None, **kwargs):
        """Execute a data view against container, and return a DataFrame.

        NOTE: This requires that the pandas module be installed on the system.

        :param view: The view id or DataView object to execute.
        :type view: str or DataView
        :param str container_id: The id of the container to execute the view against
        :param object opts: Additional options to pass to the pandas read_json function
        :param kwargs: Additional arguments to pass to the evaluate_view call.
        :return: A pandas DataFrame
        """
        import pandas

        if opts is None:
            opts = {}

        kwargs['format'] = 'json-flat'
        resp = self.read_view_data(view, container_id, decode=False, **kwargs)
        if resp:
            try:
                df = pandas.read_json(resp, orient='records', **opts)
                return df
            finally:
                resp.close()
        return None


    def save_view_data_task_manager(self, view,container_id, dest_file, **kwargs):
        view_format = kwargs.pop('format', 'json')

        if isinstance(view, six.string_types):
            resp = self.views_api.queue_saved(view, container_id, **kwargs)
        else:
            resp = self.views_api.queue_adhoc(container_id, view, **kwargs)

        data_view_execution_id = resp.json()["_id"]

        while True:
            data_view_execution = self.get_data_view_execution(resp.json()['_id'])
            if data_view_execution.state == 'failed':
                raise RuntimeError("Execution of data view failed")
            if data_view_execution.state == 'completed':
                break

        kwargs['file_format'] = view_format


        # Stream response to file
        with open(dest_file, 'wb') as out_file:
            retrieve_data_kwargs = {k: v for k, v in kwargs.items() if k not in ["filter", "skip", "limit"]}
            resp = self.get_data_view_execution_data(data_view_execution_id, **retrieve_data_kwargs)

            if resp:
                try:
                    for chunk in resp.iter_content(chunk_size=65536):
                        out_file.write(chunk)
                finally:
                    resp.close()


    def save_view_data(self, view, container_id, dest_file, **kwargs):
        """Execute a data view against container, and save the results to disk.

        :param view: The view id or DataView object to execute.
        :type view: str or DataView
        :param str container_id: The id of the container to execute the view against
        :param str dest_file: The destination file path
        :param kwargs: Additional arguments to pass to the evaluate_view call. (e.g. format='csv')
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False

        if self.get_config().get("features").get("task_manager_data_views"):
            self.save_view_data_task_manager(view,container_id, dest_file, **kwargs)
            return

        # Stream response to file
        with open(dest_file, 'wb') as out_file:
            if isinstance(view, six.string_types):
                resp = self.views_api.evaluate_view_with_http_info(view, container_id, **kwargs)
            else:
                resp = self.views_api.evaluate_view_adhoc_with_http_info(container_id, view, **kwargs)

            if resp:
                try:
                    for chunk in resp.iter_content(chunk_size=65536):
                        out_file.write(chunk)
                finally:
                    resp.close()

    # Signed upload
    def signed_upload_output_to_analysis(self, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_output_to_acquisition_analysis(self, _, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_output_to_collection_analysis(self, _, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_output_to_container_analysis(self, _, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_output_to_project_analysis(self, _, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_output_to_session_analysis(self, _, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_output_to_subject_analysis(self, _, cid, file, **kwargs):
        return self._signed_upload("analysis", cid, file, **kwargs)

    def signed_upload_file_to_acquisition(self, cid, file, **kwargs):
        return self._signed_upload("acquisition", cid, file, **kwargs)

    def signed_upload_file_to_collection(self, cid, file, **kwargs):
        return self._signed_upload("collection", cid, file, **kwargs)

    def signed_upload_file_to_container(self, cid, file, **kwargs):
        return self._signed_upload("container", cid, file, **kwargs)

    def signed_upload_file_to_project(self, cid, file, **kwargs):
        return self._signed_upload("project", cid, file, **kwargs)

    def signed_upload_file_to_session(self, cid, file, **kwargs):
        return self._signed_upload("session", cid, file, **kwargs)

    def signed_upload_file_to_subject(self, cid, file, **kwargs):
        return self._signed_upload("subject", cid, file, **kwargs)

    def _signed_upload(self, ctype, cid, file, **kwargs):
        config = self.get_config()
        features = config.get("features")
        f1 = features.get("signed_url", False) if features else False
        f2 = config.get("signed_url", False)
        if not (f1 or f2):
            log.debug("Skipping signed upload because the site does not support it")
            return None

        if not isinstance(file, (list, tuple)):
            file = [file]
        metadata_list = None
        if "metadata" in kwargs:
            metadata = kwargs["metadata"]
            # JSON-decode
            if isinstance(metadata, str):
                metadata = json.loads(metadata)
            if isinstance(metadata, (list, tuple)):
                metadata_list = metadata
        response = list()
        if metadata_list:
            if len(metadata_list) != len(file):
                raise ValueError("Metadata list must be the same length as file list")
            for subfile, md in zip(file, metadata_list):
                kwargs["metadata"] = md
                resp = self._signed_upload_single_file(ctype, cid, subfile, **kwargs)
                if resp is not None:
                    response.extend(resp)
        else:
            for subfile in file:
                resp = self._signed_upload_single_file(ctype, cid, subfile, **kwargs)
                if resp:
                    response.extend(resp)
        if not response:
            return None
        else:
            return response

    def _signed_upload_single_file(self, ctype, cid, file, **kwargs):
        fsize = None
        if isinstance(file, str):
            fname = os.path.basename(file)
            fsize = os.path.getsize(file)
            fdata = open(file, "rb")
            mimetype = mimetypes.guess_type(fname) or "application/octet-stream"
        else: # FileSpec
            fname, fdata, mimetype = file.to_file_tuple()
            if isinstance(fdata, str):
                file.size = len(fdata)
                fdata = io.StringIO(fdata)
            elif isinstance(fdata, bytes):
                file.size = len(fdata)
                fdata = io.BytesIO(fdata)

            if file.size is None:
                raise ValueError("Need to set file.size (in bytes) on input FileSpec")
            fsize = file.size

        # Create upload ticket
        metadata = kwargs.pop("metadata", {})
        if not isinstance(metadata, str):
            metadata.setdefault("name", fname)
            if fsize:
                metadata.setdefault("size", fsize)
            if ctype == "analysis":
                metadata = [metadata]
        plural_ctype = "analyses" if ctype == "analysis" else ctype + "s"
        create_ticket_response = self._ticketed_upload(plural_ctype, cid, fname,
            metadata=metadata, **kwargs)

        ticket = create_ticket_response["ticket"]
        urls = create_ticket_response["urls"][fname]
        if not isinstance(urls, list):
            urls = [urls]
        headers = create_ticket_response["headers"]

        etags_info = None
        try:
            etags_info = self._upload_to_signed_url(urls, fdata, fsize, headers)
        finally:
            if isinstance(file, str):
                fdata.close()
            if etags_info:
                kwargs["etags"] = etags_info

            # Close ticket
            close_ticket_response = self._ticketed_upload(plural_ctype, cid, None,
                None, ticket=ticket, **kwargs)
        return close_ticket_response

    def _ticketed_upload(self, ctype, cid, fname, metadata=None, ticket="", **params):
        query_params = [("ticket", ticket)]
        if "preserve_metadata" in params:
            query_params.append(("preserve_metadata", params["preserve_metadata"]))

        collection_formats = {}
        header_params = {
            "Accept": self.api_client.select_header_accept(["application/json"]),
        }
        if "x_accept_feature" in params:
            header_params["x-accept-feature"] = params["x_accept_feature"]
            collection_formats["x-accept-feature"] = ""

        kwargs = {}
        if ticket == "":
            kwargs["body"] = {"metadata": metadata or {}, "filenames": [fname]}
            kwargs["response_type"] = object
        else:
            kwargs["response_type"] = "list[FileOutput]"
            if "etags" in params:
                kwargs["body"] = {"multipart": params["etags"]}

        kwargs.setdefault("_return_http_data_only", True)
        kwargs.setdefault("_preload_content", True)
        kwargs["collection_formats"] = collection_formats
        kwargs["auth_settings"] = ["ApiKey"]

        return self.api_client.call_api("/{ctype}/{container_id}/files", "POST",
            {"ctype": ctype, "container_id": cid},
            query_params,
            header_params,
            **kwargs)


    def _upload_to_signed_url(self, urls, fdata, fsize, headers):
        is_s3_upload = ".s3." in urls[0] or ".amazonaws." in urls[0]
        e_tags = list()
        upload_id = None

        num_urls = len(urls)
        part_size = math.ceil(fsize / num_urls)
        for part_num, url in enumerate(urls):
            remaining = fsize - part_size * part_num
            content_length = remaining if remaining < part_size else part_size
            reader = PartialReader(fdata, content_length)
            upload_response = self.api_client.rest_client.session.put(
                url, data=reader, headers=headers
            )
            upload_response.raise_for_status()
            if is_s3_upload:
                parsed = urlparse(url)
                upload_id = parse_qs(parsed.query)["uploadId"][0]
                e_tags.append(upload_response.headers["ETag"].strip('"'))
            upload_response.close()

        if is_s3_upload and e_tags and upload_id:
            return {"e_tags": e_tags, "upload_id": upload_id}
        else:
            return {}


    def shutdown(self):
        """Release any outstanding resources"""
        self.api_client.shutdown()

